@@ -1,5 +1,5 @@
 /* ------------------------------------------------------------------------ */
-/* Copyright 2002-2015, OpenNebula Project, OpenNebula Systems              */
+/* Copyright 2002-2016, OpenNebula Project, OpenNebula Systems              */
 /*                                                                          */
 /* Licensed under the Apache License, Version 2.0 (the "License"); you may  */
 /* not use this file except in compliance with the License. You may obtain  */
@@ -76,16 +76,17 @@ public:
      */
     enum DiskType
     {
-        FILE          = 0, /** < File-based disk */
-        CD_ROM        = 1, /** < An ISO9660 disk */
-        BLOCK         = 2, /** < Block-device disk */
-        RBD           = 3, /** < CEPH RBD disk */
-        RBD_CDROM     = 4, /** < CEPH RBD CDROM disk */
-        GLUSTER       = 5, /** < Gluster Block Device */
-        GLUSTER_CDROM = 6, /** < Gluster CDROM Device Device */
-        SHEEPDOG      = 7, /** < Sheepdog Block Device */
+        FILE           = 0, /** < File-based disk */
+        CD_ROM         = 1, /** < An ISO9660 disk */
+        BLOCK          = 2, /** < Block-device disk */
+        RBD            = 3, /** < CEPH RBD disk */
+        RBD_CDROM      = 4, /** < CEPH RBD CDROM disk */
+        GLUSTER        = 5, /** < Gluster Block Device */
+        GLUSTER_CDROM  = 6, /** < Gluster CDROM Device Device */
+        SHEEPDOG       = 7, /** < Sheepdog Block Device */
         SHEEPDOG_CDROM = 8, /** < Sheepdog CDROM Device Device */
-        NONE          = 255 /** < No disk type, error situation */
+        ISCSI          = 9, /** < iSCSI Volume (Devices Datastore) */
+        NONE           = 255 /** < No disk type, error situation */
     };
 
     /**
@@ -106,6 +107,7 @@ public:
             case GLUSTER_CDROM:  return "GLUSTER_CDROM" ; break;
             case SHEEPDOG:       return "SHEEPDOG" ; break;
             case SHEEPDOG_CDROM: return "SHEEPDOG_CDROM" ; break;
+            case ISCSI:          return "ISCSI" ; break;
             default:             return "";
         }
     };
@@ -130,7 +132,9 @@ public:
         ERROR     = 5, /** < Error state the operation FAILED*/
         CLONE     = 6, /** < Image is being cloned */
         DELETE    = 7, /** < DS is deleting the image */
-        USED_PERS = 8  /** < Image is in use and persistent */
+        USED_PERS = 8, /** < Image is in use and persistent */
+        LOCKED_USED = 9,      /** < FS operation in progress, VMs waiting */
+        LOCKED_USED_PERS = 10 /** < FS operation in progress, VMs waiting. Persistent */
     };
 
     /**
@@ -142,16 +146,18 @@ public:
     {
         switch(state)
         {
-            case INIT:      return "INIT";      break;
-            case READY:     return "READY";     break;
-            case USED:      return "USED";      break;
-            case DISABLED:  return "DISABLED";  break;
-            case LOCKED:    return "LOCKED";    break;
-            case ERROR:     return "ERROR";     break;
-            case CLONE:     return "CLONE";     break;
-            case DELETE:    return "DELETE";    break;
-            case USED_PERS: return "USED";      break;
-            default:        return "";
+            case INIT:              return "INIT";          break;
+            case READY:             return "READY";         break;
+            case USED:              return "USED";          break;
+            case DISABLED:          return "DISABLED";      break;
+            case LOCKED:            return "LOCKED";        break;
+            case ERROR:             return "ERROR";         break;
+            case CLONE:             return "CLONE";         break;
+            case DELETE:            return "DELETE";        break;
+            case USED_PERS:         return "USED";          break;
+            case LOCKED_USED:       return "LOCKED_USED";   break;
+            case LOCKED_USED_PERS:  return "LOCKED_USED";   break;
+            default:                return "";
         }
     };
 
@@ -257,10 +263,12 @@ public:
      *  Sets the image state
      *     @param state of image
      */
-    void set_state(ImageState _state)
-    {
-        state = _state;
-    }
+    void set_state(ImageState _state);
+
+    /**
+     * Moves the image from the locked* states to ready, used, used_persistent
+     */
+    void set_state_unlock();
 
     /**
      *  Return the ID of the image we are cloning this one from (if any)
@@ -292,7 +300,7 @@ public:
 
     int dec_running (int vm_id)
     {
-        if ( vm_collection.del_collection_id(vm_id) == 0 )
+        if ( vm_collection.del(vm_id) == 0 )
         {
             running_vms--;
         }
@@ -302,7 +310,7 @@ public:
 
     int inc_running(int vm_id)
     {
-        if ( vm_collection.add_collection_id(vm_id) == 0 )
+        if ( vm_collection.add(vm_id) == 0 )
         {
             running_vms++;
         }
@@ -315,14 +323,30 @@ public:
         return running_vms;
     }
 
+    set<int> get_running_ids() const
+    {
+        return vm_collection.clone();
+    }
+
     int get_cloning() const
     {
         return cloning_ops;
     }
 
-    int dec_cloning(int img_id)
+    int dec_cloning(PoolObjectSQL::ObjectType ot, int oid)
     {
-        if ( img_clone_collection.del_collection_id(img_id) == 0 )
+        int rc = -1;
+
+        if (ot == PoolObjectSQL::IMAGE)
+        {
+            rc = img_clone_collection.del(oid);
+        }
+        else //if (ot == PoolObjectSQL::MARKETPLACEAPP)
+        {
+            rc = app_clone_collection.del(oid);
+        }
+
+        if ( rc == 0 )
         {
             cloning_ops--;
         }
@@ -330,9 +354,20 @@ public:
         return cloning_ops;
     }
 
-    int inc_cloning(int img_id)
+    int inc_cloning(PoolObjectSQL::ObjectType ot, int oid)
     {
-        if ( img_clone_collection.add_collection_id(img_id) == 0 )
+        int rc = -1;
+
+        if (ot == PoolObjectSQL::IMAGE)
+        {
+            rc = img_clone_collection.add(oid);
+        }
+        else //if (ot == PoolObjectSQL::MARKETPLACEAPP)
+        {
+            rc = app_clone_collection.add(oid);
+        }
+
+        if ( rc == 0 )
         {
             cloning_ops++;
         }
@@ -379,6 +414,8 @@ public:
             case USED:
             case CLONE:
             case USED_PERS:
+            case LOCKED_USED:
+            case LOCKED_USED_PERS:
                 oss << "Image cannot be in state " << state_to_str(state) <<".";
                 error_str = oss.str();
                 return -1;
@@ -579,7 +616,7 @@ private:
     int running_vms;
 
     /**
-     * Number of pending cloning operations
+     * Number of pending cloning operations, for both images and apps
      */
     int cloning_ops;
 
@@ -609,6 +646,11 @@ private:
      */
     ObjectCollection img_clone_collection;
 
+    /**
+     *  Stores a collection with the Marketplace apps cloning this image
+     */
+    ObjectCollection app_clone_collection;
+
     /**
      * Snapshot list for this image
      */
