@@ -1,5 +1,5 @@
 /* -------------------------------------------------------------------------- */
-/* Copyright 2002-2015, OpenNebula Project, OpenNebula Systems                */
+/* Copyright 2002-2016, OpenNebula Project, OpenNebula Systems                */
 /*                                                                            */
 /* Licensed under the Apache License, Version 2.0 (the "License"); you may    */
 /* not use this file except in compliance with the License. You may obtain    */
@@ -41,15 +41,14 @@ class ImagePool : public PoolSQL
 public:
 
     ImagePool(
-            SqlDB *                             db,
-            const string&                       __default_type,
-            const string&                       __default_dev_prefix,
-            const string&                       __default_cdrom_dev_prefix,
-            vector<const Attribute *>&          restricted_attrs,
-            vector<const Attribute *>           hook_mads,
-            const string&                       remotes_location,
-            const vector<const Attribute *>&    _inherit_image_attrs,
-            const vector<const Attribute *>&    _inherit_datastore_attrs);
+            SqlDB *                          db,
+            const string&                    __default_type,
+            const string&                    __default_dev_prefix,
+            const string&                    __default_cdrom_dev_prefix,
+            vector<const SingleAttribute *>& restricted_attrs,
+            vector<const VectorAttribute *>& hook_mads,
+            const string&                    remotes_location,
+            const vector<const SingleAttribute *>& _inherit_image_attrs);
 
     ~ImagePool(){};
 
@@ -66,6 +65,7 @@ public:
      *    @param ds_type disk type for the image
      *    @param ds_data the datastore data
      *    @param ds_type the datastore type
+     *    @param extra_data extra data that will be sent to the driver
      *    @param source_img_id If the new Image is a clone, this must be the
      *      source Image ID. Otherwise, it must be set to -1
      *    @param oid the id assigned to the Image
@@ -86,6 +86,9 @@ public:
         Image::DiskType          disk_type,
         const string&            ds_data,
         Datastore::DatastoreType ds_type,
+        const string&            ds_mad,
+        const string&            tm_mad,
+        const string&            extra_data,
         int                      source_img_id,
         int *                    oid,
         string&                  error_str);
@@ -116,16 +119,6 @@ public:
         return static_cast<Image *>(PoolSQL::get(name,uid,lock));
     };
 
-    /**
-     *  Update a particular Image
-     *    @param image pointer to Image
-     *    @return 0 on success
-     */
-    int update(Image * image)
-    {
-        return image->update(db);
-    };
-
     /**
      *  Bootstraps the database table(s) associated to the Image pool
      *    @return 0 on success
@@ -218,12 +211,22 @@ public:
      */
     static int get_disk_uid(VectorAttribute *  disk, int _uid);
 
-    /**
-     *  Get the disk id based on its string representation. Used in VM parsers
-     *    @param id_s the string id
-     *    @return the id in int form
-     */
-     static int get_disk_id(const string& id_s);
+     /**
+      *  Gets the IDs of the images associated to a set of disks
+      *    @param dsk a vector with the DISK attributes
+      *    @param ids set of image ids
+      *    @param uid effective user id making the call
+      */
+     void get_image_ids(vector<VectorAttribute *>& dsk, set<int>& ids, int uid);
+
+     /**
+      *  Gets the IDs of the images associated to a set of disks
+      *    @param disk DISK attribute
+      *    @param ids the image id, if found
+      *    @param uid effective user id making the call
+      *    @return 0 if the disk uses an image, -1 otherwise
+      */
+     int get_image_id(VectorAttribute * disk, int &id, int uid);
 
 private:
     //--------------------------------------------------------------------------
@@ -248,12 +251,7 @@ private:
     /**
      * Image attributes to be inherited into the VM disk
      */
-    vector<string> inherit_image_attrs;
-
-    /**
-     * Datastore attributes to be inherited into the VM disk
-     */
-    vector<string> inherit_datastore_attrs;
+    vector<string> inherit_attrs;
 
     //--------------------------------------------------------------------------
     // Pool Attributes
