@@ -1,5 +1,5 @@
 /* -------------------------------------------------------------------------- */
-/* Copyright 2002-2015, OpenNebula Project, OpenNebula Systems                */
+/* Copyright 2002-2016, OpenNebula Project, OpenNebula Systems                */
 /*                                                                            */
 /* Licensed under the Apache License, Version 2.0 (the "License"); you may    */
 /* not use this file except in compliance with the License. You may obtain    */
@@ -88,7 +88,7 @@ private:
      * ImageTemplate::check
      * @param rattrs Attributes to restrict
      */
-    static void set_restricted_attributes(vector<const Attribute *>& rattrs)
+    static void set_restricted_attributes(vector<const SingleAttribute *>& rattrs)
     {
         Template::set_restricted_attributes(rattrs, restricted_attributes);
     };
