@@ -329,7 +329,7 @@ public:
      */
     static string code_version()
     {
-        return "5.0.0"; // bump version
+        return "5.0.2"; // bump version
     }
 
     /**
@@ -438,6 +438,16 @@ public:
         return get_conf_attribute("MARKET_MAD_CONF", mk_name, value);
     };
 
+    /**
+     *  Gets an Auth driver configuration attribute
+     */
+    int get_auth_conf_attribute(
+        const string& driver_name,
+        const VectorAttribute* &value) const
+    {
+        return get_conf_attribute("AUTH_MAD_CONF", driver_name, value);
+    };
+
     /**
      *  Gets an XML document with all of the configuration attributes
      *    @return the XML
