@@ -1,5 +1,5 @@
 /* -------------------------------------------------------------------------- */
-/* Copyright 2002-2015, OpenNebula Project, OpenNebula Systems                */
+/* Copyright 2002-2016, OpenNebula Project, OpenNebula Systems                */
 /*                                                                            */
 /* Licensed under the Apache License, Version 2.0 (the "License"); you may    */
 /* not use this file except in compliance with the License. You may obtain    */
@@ -21,6 +21,7 @@
 #include <sstream>
 #include <vector>
 #include <set>
+#include <algorithm>
 
 namespace one_util
 {
@@ -150,6 +151,19 @@ namespace one_util
         return oss.str();
     }
 
+    /**
+     * Joins the given element with the delimiter
+     *
+     * @param values set of values
+     * @param delim delimiter character
+     * @return the joined strings
+     */
+    template <class T>
+    std::string join(const std::set<T> values, char delim)
+    {
+        return join(values.begin(), values.end(), delim);
+    }
+
     /**
      * Creates a string from the given float, using fixed notation. If the
      * number has any decimals, they will be truncated to 2.
@@ -159,6 +173,33 @@ namespace one_util
      */
     std::string float_to_str(const float &num);
 
+    /**
+     *  Returns a scaped version of a value in the from "<op><val><cl>"
+     *    @param v the value to be escaped
+     *    @param op the opening escape string
+     *    @param cl the closing escape string
+     */
+    template <typename ValueType> inline
+    std::string escape(const ValueType& v, const char * op, const char * cl)
+    {
+        std::ostringstream oss;
+
+        oss << op << v << cl;
+
+        return oss.str();
+    }
+
+    template <typename ValueType> inline
+    std::string escape_xml(const ValueType &v)
+    {
+        return escape(v, "<![CDATA[", "]]>");
+    }
+
+    template <typename ValueType> inline
+    std::string escape_xml_attr(const ValueType &v)
+    {
+        return escape(v, "'", "'");
+    }
     /**
      * Checks if a strings matches a regular expression
      *
@@ -167,6 +208,54 @@ namespace one_util
      * @return 0 on match, another value otherwise
      */
     int regex_match(const char *pattern, const char *subject);
+
+    /**
+     * Trim an string using the isspace function
+     * @param the string
+     * @return trimed string
+     */
+    std::string trim(const std::string& str);
+
+    /**
+     * Returns a copy of st with the all occurrences of "find" substituted
+     * for "replacement"
+     * @param st string input
+     * @param sfind string to search for
+     * @param replacement string to replace occurrences with
+     * @return a string copy
+     */
+    std::string gsub(const std::string& st, const std::string& sfind,
+            const std::string& replacement);
+
+    template <class T>
+    std::set<T> set_intersection(const std::set<T> &first, const std::set<T> &second)
+    {
+        std::set<T> output;
+
+        std::set_intersection(
+                first.begin(), first.end(), second.begin(), second.end(),
+                std::inserter(output, output.begin()));
+
+        return output;
+    }
+
+	/**
+     *  Compress the input string unsing zlib
+     *    @param in input string
+     *    @param bool64 true to base64 encode output
+     *    @return pointer to the compressed sting (must be freed) or 0 in case
+     *    of error
+     */
+	std::string * zlib_compress(const std::string& in, bool base64);
+
+	/**
+     *  Decompress the input string unsing zlib
+     *    @param in input string
+     *    @param base64 true if the input is base64 encoded
+     *    @return pointer to the decompressed sting (must be freed) or 0 in case
+     *    of error
+     */
+	std::string * zlib_decompress(const std::string& in, bool base64);
 };
 
 #endif /* _NEBULA_UTIL_H_ */
