@@ -1,5 +1,5 @@
 /* -------------------------------------------------------------------------- */
-/* Copyright 2002-2015, OpenNebula Project, OpenNebula Systems                */
+/* Copyright 2002-2016, OpenNebula Project, OpenNebula Systems                */
 /*                                                                            */
 /* Licensed under the Apache License, Version 2.0 (the "License"); you may    */
 /* not use this file except in compliance with the License. You may obtain    */
@@ -29,16 +29,20 @@ using namespace std;
 class RequestManagerChmod : public Request
 {
 protected:
-    RequestManagerChmod(const string& method_name,
-                        const string& help)
-        :Request(method_name, "A:siiiiiiiiii", help){};
+    RequestManagerChmod(const string& method_name, const string& help,
+        const string& params = "A:siiiiiiiiii"):
+            Request(method_name, params, help){};
 
     ~RequestManagerChmod(){};
 
     /* -------------------------------------------------------------------- */
 
-    virtual void request_execute(xmlrpc_c::paramList const& _paramList,
-                                 RequestAttributes& att);
+    void request_execute(xmlrpc_c::paramList const& _paramList,
+        RequestAttributes& att);
+
+    virtual ErrorCode chmod(PoolSQL * pool, int oid, int owner_u, int owner_m,
+        int owner_a, int group_u, int group_m, int group_a, int other_u,
+        int other_m, int other_a, bool recursive, RequestAttributes& att);
 };
 
 /* ------------------------------------------------------------------------- */
@@ -66,8 +70,8 @@ class TemplateChmod : public RequestManagerChmod
 {
 public:
     TemplateChmod():
-        RequestManagerChmod("TemplateChmod",
-                            "Changes permission bits of a virtual machine template")
+        RequestManagerChmod("TemplateChmod", "Changes permission bits of a "
+            "virtual machine template", "A:siiiiiiiiiib")
     {
         Nebula& nd  = Nebula::instance();
         pool        = nd.get_tpool();
@@ -75,9 +79,23 @@ public:
     };
 
     ~TemplateChmod(){};
+
+    ErrorCode request_execute(PoolSQL * pool, int oid, int owner_u, int owner_m,
+        int owner_a, int group_u, int group_m, int group_a, int other_u,
+        int other_m, int other_a, bool recursive, RequestAttributes& att)
+    {
+        return chmod(pool, oid, owner_u, owner_m, owner_a, group_u, group_m,
+                group_a, other_u, other_m, other_a, recursive, att);
+    }
+
+protected:
+
+    ErrorCode chmod(PoolSQL * pool, int oid, int owner_u, int owner_m,
+        int owner_a, int group_u, int group_m, int group_a, int other_u,
+        int other_m, int other_a, bool recursive, RequestAttributes& att);
 };
 
-/* ------------------------------------------------------------------------- */
+/* ------------------------------------------------------------- */
 /* ------------------------------------------------------------------------- */
 
 class VirtualNetworkChmod: public RequestManagerChmod
@@ -93,7 +111,6 @@ public:
     };
 
     ~VirtualNetworkChmod(){};
-
 };
 
 /* ------------------------------------------------------------------------- */
@@ -113,6 +130,13 @@ public:
 
     ~ImageChmod(){};
 
+    ErrorCode request_execute(PoolSQL * pool, int oid, int owner_u, int owner_m,
+        int owner_a, int group_u, int group_m, int group_a, int other_u,
+        int other_m, int other_a, RequestAttributes& att)
+    {
+        return chmod(pool, oid, owner_u, owner_m, owner_a, group_u, group_m,
+                group_a, other_u, other_m, other_a, false, att);
+    }
 };
 
 /* ------------------------------------------------------------------------- */
@@ -131,7 +155,6 @@ public:
     };
 
     ~DatastoreChmod(){};
-
 };
 
 /* ------------------------------------------------------------------------- */
@@ -168,10 +191,62 @@ public:
     };
 
     ~SecurityGroupChmod(){};
+};
 
+/* ------------------------------------------------------------------------- */
+/* ------------------------------------------------------------------------- */
+
+class VirtualRouterChmod: public RequestManagerChmod
+{
+public:
+    VirtualRouterChmod():
+        RequestManagerChmod("VirtualRouterChmod",
+                            "Changes permission bits of a virtual router")
+    {
+        Nebula& nd  = Nebula::instance();
+        pool        = nd.get_vrouterpool();
+        auth_object = PoolObjectSQL::VROUTER;
+    };
+
+    ~VirtualRouterChmod(){};
+};
+
+/* ------------------------------------------------------------------------- */
+/* ------------------------------------------------------------------------- */
+
+class MarketPlaceChmod: public RequestManagerChmod
+{
+public:
+    MarketPlaceChmod():
+        RequestManagerChmod("MarketPlaceChmod",
+                           "Changes permission bits of a marketplace")
+    {
+        Nebula& nd  = Nebula::instance();
+        pool        = nd.get_marketpool();
+        auth_object = PoolObjectSQL::MARKETPLACE;
+    };
+
+    ~MarketPlaceChmod(){};
+};
+
+/* ------------------------------------------------------------------------- */
+/* ------------------------------------------------------------------------- */
+
+class MarketPlaceAppChmod: public RequestManagerChmod
+{
+public:
+    MarketPlaceAppChmod():
+        RequestManagerChmod("MarketPlaceAppChmod",
+                           "Changes permission bits of a marketplace app")
+    {
+        Nebula& nd  = Nebula::instance();
+        pool        = nd.get_apppool();
+        auth_object = PoolObjectSQL::MARKETPLACEAPP;
+    };
+
+    ~MarketPlaceAppChmod(){};
 };
 
-/* -------------------------------------------------------------------------- */
 /* -------------------------------------------------------------------------- */
 /* -------------------------------------------------------------------------- */
 
