@@ -1,5 +1,5 @@
 /* -------------------------------------------------------------------------- */
-/* Copyright 2002-2015, OpenNebula Project, OpenNebula Systems                */
+/* Copyright 2002-2016, OpenNebula Project, OpenNebula Systems                */
 /*                                                                            */
 /* Licensed under the Apache License, Version 2.0 (the "License"); you may    */
 /* not use this file except in compliance with the License. You may obtain    */
@@ -32,9 +32,9 @@ class TransferManager : public MadManager, public ActionListener
 public:
 
     TransferManager(
-        VirtualMachinePool *        _vmpool,
-        HostPool *                  _hpool,
-        vector<const Attribute*>&   _mads):
+        VirtualMachinePool * _vmpool,
+        HostPool *           _hpool,
+        vector<const VectorAttribute*>& _mads):
             MadManager(_mads),
             vmpool(_vmpool),
             hpool(_hpool)
@@ -51,6 +51,7 @@ public:
         PROLOG_RESUME,
         PROLOG_ATTACH,
         EPILOG,
+        EPILOG_LOCAL,
         EPILOG_STOP,
         EPILOG_DELETE,
         EPILOG_DELETE_PREVIOUS,
@@ -123,16 +124,36 @@ public:
             ostream&                xfr,
             ostringstream&          error);
 
+    /**
+     * Inserts a context command in the xfs stream
+     *
+     * @param vm The VM
+     * @param token_password Owner user's token password
+     * @param system_tm_mad The Transfer Manager for the system datastore
+     * @param disk_id of the context disk
+     * @param xfr Stream where the transfer command will be written
+     *
+     * @return -1 in case of error, 0 if the VM has no context, 1 on success
+     */
+    int prolog_context_command(
+            VirtualMachine *        vm,
+            const string&           token_password,
+            string&                 system_tm_mad,
+            int&                    disk_id,
+            ostream&                xfr);
+
     /**
      * Inserts a transfer command in the xfs stream
      *
      * @param vm The VM
+     * @param host where the operation will be performed fe or host
      * @param disk Disk to transfer
      * @param disk_index Disk index
      * @param xfr Stream where the transfer command will be written
      */
     void epilog_transfer_command(
             VirtualMachine *        vm,
+            const string&           host,
             const VectorAttribute * disk,
             ostream&                xfr);
     /**
@@ -276,7 +297,7 @@ private:
     /**
      *  This function starts the epilog sequence
      */
-    void epilog_action(int vid);
+    void epilog_action(bool local, int vid);
 
     /**
      *  This function starts the epilog_stop sequence
