@@ -1249,10 +1249,16 @@ public:
     static int release_network_leases(const VectorAttribute * nic, int vmid);
 
     /**
-     * Returns a set of the security group IDs in use in this VM
+     * Returns a set of the security group IDs in use in this VM. VirtualMachine
+     * and static version.
      * @param sgs a set of security group IDs
      */
-    void get_security_groups(set<int>& sgs) const;
+    void get_security_groups(set<int>& sgs) const
+    {
+        get_security_groups(static_cast<VirtualMachineTemplate *>(obj_template), sgs);
+    }
+
+    static void get_security_groups(VirtualMachineTemplate *tmpl, set<int>& sgs);
 
     /**
      *  Remove the rules associated to the given security group rules
@@ -1922,6 +1928,14 @@ private:
      */
     bool generate_network_context(VectorAttribute * context);
 
+    /**
+     *  Generate the PCI related CONTEXT setions, i.e. PCI_*. This function
+     *  is also adds basic network attributes for pass-through NICs
+     *    @param context attribute of the VM
+     *    @return true if the net context was generated.
+     */
+    bool generate_pci_context(VectorAttribute * context);
+
     /**
      *  Generate the ONE_GATE token & url
      *    @param context attribute of the VM
