@@ -884,6 +884,7 @@ TM_FS_LVM_FILES="src/tm_mad/fs_lvm/clone \
 TM_QCOW2_FILES="src/tm_mad/qcow2/clone \
                  src/tm_mad/qcow2/delete \
                  src/tm_mad/qcow2/ln \
+                 src/tm_mad/qcow2/monitor \
                  src/tm_mad/qcow2/mkswap \
                  src/tm_mad/qcow2/mkimage \
                  src/tm_mad/qcow2/mv \
@@ -914,6 +915,7 @@ TM_SSH_FILES="src/tm_mad/ssh/clone \
               src/tm_mad/ssh/snap_delete \
               src/tm_mad/ssh/snap_revert \
               src/tm_mad/ssh/monitor \
+              src/tm_mad/ssh/monitor_ds \
               src/tm_mad/ssh/cpds"
 
 TM_DUMMY_FILES="src/tm_mad/dummy/clone \
@@ -1529,13 +1531,6 @@ SUNSTONE_PUBLIC_FONT_AWSOME="src/sunstone/public/bower_components/fontawesome/fo
                 src/sunstone/public/bower_components/fontawesome/fonts/fontawesome-webfont.ttf \
                 src/sunstone/public/bower_components/fontawesome/fonts/fontawesome-webfont.svg"
 
-SUNSTONE_PUBLIC_VENDOR_CRYPTOJS="\
-src/sunstone/public/vendor/crypto-js/NOTICE \
-src/sunstone/public/vendor/crypto-js/sha1-min.js \
-src/sunstone/public/vendor/crypto-js/core-min.js \
-src/sunstone/public/vendor/crypto-js/enc-base64-min.js \
-src/sunstone/public/vendor/crypto-js/NEW-BSD-LICENSE.txt"
-
 SUNSTONE_PUBLIC_IMAGES_FILES="src/sunstone/public/images/ajax-loader.gif \
                         src/sunstone/public/images/favicon.ico \
                         src/sunstone/public/images/login_over.png \
@@ -1543,28 +1538,13 @@ SUNSTONE_PUBLIC_IMAGES_FILES="src/sunstone/public/images/ajax-loader.gif \
                         src/sunstone/public/images/advanced_layout.png \
                         src/sunstone/public/images/cloud_layout.png \
                         src/sunstone/public/images/vcenter_layout.png \
-                        src/sunstone/public/images/opennebula-sunstone-big.png \
-                        src/sunstone/public/images/opennebula-sunstone-small.png \
+                        src/sunstone/public/images/opennebula-5.0.png \
                         src/sunstone/public/images/opennebula-sunstone-v4.0.png \
                         src/sunstone/public/images/opennebula-sunstone-v4.14-small.png \
                         src/sunstone/public/images/one_small_logo.png \
                         src/sunstone/public/images/panel.png \
                         src/sunstone/public/images/panel_short.png \
                         src/sunstone/public/images/pbar.gif \
-                        src/sunstone/public/images/Refresh-icon.png \
-                        src/sunstone/public/images/red_bullet.png \
-                        src/sunstone/public/images/yellow_bullet.png \
-                        src/sunstone/public/images/green_bullet.png \
-                        src/sunstone/public/images/vnc_off.png \
-                        src/sunstone/public/images/vnc_on.png \
-                        src/sunstone/public/images/network_icon.png \
-                        src/sunstone/public/images/system_icon.png \
-                        src/sunstone/public/images/server_icon.png  \
-                        src/sunstone/public/images/sort_asc.png \
-                        src/sunstone/public/images/sort_asc_disabled.png \
-                        src/sunstone/public/images/sort_both.png \
-                        src/sunstone/public/images/sort_desc.png \
-                        src/sunstone/public/images/sort_desc_disabled.png\
 "
 
 SUNSTONE_PUBLIC_LOGOS_FILES="src/sunstone/public/images/logos/arch.png \
