@@ -1,5 +1,5 @@
 /* ------------------------------------------------------------------------ */
-/* Copyright 2002-2015, OpenNebula Project, OpenNebula Systems              */
+/* Copyright 2002-2016, OpenNebula Project, OpenNebula Systems              */
 /*                                                                          */
 /* Licensed under the Apache License, Version 2.0 (the "License"); you may  */
 /* not use this file except in compliance with the License. You may obtain  */
@@ -28,6 +28,8 @@
 #include "AuthManager.h"
 #include "UserPool.h"
 #include "NebulaUtil.h"
+#include "LifeCycleManager.h"
+#include "Nebula.h"
 
 #define TO_UPPER(S) transform(S.begin(),S.end(),S.begin(),(int(*)(int))toupper)
 
@@ -57,6 +59,7 @@ Image::Image(int             _uid,
         ds_name(""),
         vm_collection("VMS"),
         img_clone_collection("CLONES"),
+        app_clone_collection("APP_CLONES"),
         snapshots(-1),
         target_snapshot(-1)
 {
@@ -105,6 +108,7 @@ int Image::insert(SqlDB *db, string& error_str)
     string source_attr;
     string saved_id;
     string size_attr;
+    string driver;
 
     istringstream iss;
     ostringstream oss;
@@ -183,22 +187,11 @@ int Image::insert(SqlDB *db, string& error_str)
     erase_template_attribute("PATH", path);
     erase_template_attribute("SOURCE", source);
 
-    if (!is_saving()) //Not a saving image
+    if (!is_saving())
     {
-        if ( source.empty() && path.empty() )
+        if ( source.empty() && path.empty() && type != DATABLOCK )
         {
-            if (type != DATABLOCK)
-            {
-                goto error_no_path;
-            }
-
-            erase_template_attribute("FSTYPE", fs_type);
-
-            // DATABLOCK image needs FSTYPE
-            if (fs_type.empty())
-            {
-                fs_type = "raw";
-            }
+            goto error_no_path;
         }
         else if ( !source.empty() && !path.empty() )
         {
@@ -221,7 +214,7 @@ int Image::insert(SqlDB *db, string& error_str)
     return rc;
 
 error_no_path:
-    error_str = "No PATH in template.";
+    error_str = "No PATH nor SOURCE in template.";
     goto error_common;
 
 error_path_and_source:
@@ -337,6 +330,7 @@ string& Image::to_xml(string& xml) const
     ostringstream oss;
     string        vm_collection_xml;
     string        clone_collection_xml;
+    string        app_clone_collection_xml;
     string        snapshots_xml;
 
     oss <<
@@ -352,9 +346,9 @@ string& Image::to_xml(string& xml) const
             "<DISK_TYPE>"      << disk_type       << "</DISK_TYPE>"   <<
             "<PERSISTENT>"     << persistent_img  << "</PERSISTENT>"  <<
             "<REGTIME>"        << regtime         << "</REGTIME>"     <<
-            "<SOURCE><![CDATA["<< source          << "]]></SOURCE>"   <<
-            "<PATH><![CDATA["  << path            << "]]></PATH>"     <<
-            "<FSTYPE><![CDATA["<< fs_type         << "]]></FSTYPE>"   <<
+            "<SOURCE>"         << one_util::escape_xml(source) << "</SOURCE>" <<
+            "<PATH>"           << one_util::escape_xml(path)   << "</PATH>"   <<
+            "<FSTYPE>"         << one_util::escape_xml(fs_type)<< "</FSTYPE>" <<
             "<SIZE>"           << size_mb         << "</SIZE>"        <<
             "<STATE>"          << state           << "</STATE>"       <<
             "<RUNNING_VMS>"    << running_vms     << "</RUNNING_VMS>" <<
@@ -365,6 +359,7 @@ string& Image::to_xml(string& xml) const
             "<DATASTORE>"      << ds_name         << "</DATASTORE>"   <<
             vm_collection.to_xml(vm_collection_xml)                   <<
             img_clone_collection.to_xml(clone_collection_xml)         <<
+            app_clone_collection.to_xml(app_clone_collection_xml)     <<
             obj_template->to_xml(template_xml)                        <<
             snapshots.to_xml(snapshots_xml)                           <<
         "</IMAGE>";
@@ -402,14 +397,15 @@ int Image::from_xml(const string& xml)
     rc += xpath(int_type,       "/IMAGE/TYPE",      0);
     rc += xpath(int_disk_type,  "/IMAGE/DISK_TYPE", 0);
     rc += xpath(persistent_img, "/IMAGE/PERSISTENT",0);
-    rc += xpath(regtime,        "/IMAGE/REGTIME",   0);
+    rc += xpath<time_t>(regtime,"/IMAGE/REGTIME",   0);
 
-    rc += xpath(source,         "/IMAGE/SOURCE",        "not_found");
-    rc += xpath(size_mb,        "/IMAGE/SIZE",          0);
-    rc += xpath(int_state,      "/IMAGE/STATE",         0);
-    rc += xpath(running_vms,    "/IMAGE/RUNNING_VMS",   -1);
-    rc += xpath(cloning_ops,    "/IMAGE/CLONING_OPS",   -1);
-    rc += xpath(cloning_id,     "/IMAGE/CLONING_ID",    -1);
+    rc += xpath<long long>(size_mb, "/IMAGE/SIZE", 0);
+
+    rc += xpath(source,     "/IMAGE/SOURCE",     "not_found");
+    rc += xpath(int_state,  "/IMAGE/STATE",      0);
+    rc += xpath(running_vms,"/IMAGE/RUNNING_VMS",-1);
+    rc += xpath(cloning_ops,"/IMAGE/CLONING_OPS",-1);
+    rc += xpath(cloning_id, "/IMAGE/CLONING_ID", -1);
 
     rc += xpath(target_snapshot, "/IMAGE/TARGET_SNAPSHOT", -1);
 
@@ -441,31 +437,9 @@ int Image::from_xml(const string& xml)
 
     content.clear();
 
-    ObjectXML::get_nodes("/IMAGE/VMS", content);
-
-    if (content.empty())
-    {
-        return -1;
-    }
-
-    rc += vm_collection.from_xml_node(content[0]);
-
-    ObjectXML::free_nodes(content);
-
-    content.clear();
-
-    ObjectXML::get_nodes("/IMAGE/CLONES", content);
-
-    if (content.empty())
-    {
-        return -1;
-    }
-
-    rc += img_clone_collection.from_xml_node(content[0]);
-
-    ObjectXML::free_nodes(content);
-
-    content.clear();
+    rc += vm_collection.from_xml(this, "/IMAGE/");
+    rc += img_clone_collection.from_xml(this, "/IMAGE/");
+    rc += app_clone_collection.from_xml(this, "/IMAGE/");
 
     ObjectXML::get_nodes("/IMAGE/SNAPSHOTS", content);
 
@@ -567,6 +541,8 @@ void Image::disk_attribute( VectorAttribute *       disk,
         disk->replace("DRIVER",template_driver);
     }
 
+    disk->replace("IMAGE_STATE", state);
+
     //--------------------------------------------------------------------------
     //   READONLY attribute
     //--------------------------------------------------------------------------
@@ -811,6 +787,10 @@ Image::DiskType Image::str_to_disk_type(string& s_disk_type)
     {
         type = Image::BLOCK;
     }
+    else if (s_disk_type == "ISCSI")
+    {
+        type = Image::ISCSI;
+    }
     else if (s_disk_type == "CDROM")
     {
         type = Image::CD_ROM;
@@ -830,3 +810,81 @@ Image::DiskType Image::str_to_disk_type(string& s_disk_type)
 
     return type;
 }
+
+/* ------------------------------------------------------------------------ */
+/* ------------------------------------------------------------------------ */
+
+void Image::set_state(ImageState _state)
+{
+    if (_state == ERROR && (state == LOCKED_USED || state == LOCKED_USED_PERS))
+    {
+        LifeCycleManager* lcm = Nebula::instance().get_lcm();
+        const set<int>& vms   = vm_collection.get_collection();
+
+        for(set<int>::iterator i = vms.begin(); i != vms.end(); i++)
+        {
+            lcm->trigger(LifeCycleManager::DISK_LOCK_FAILURE, *i);
+        }
+    }
+
+    state = _state;
+}
+
+/* ------------------------------------------------------------------------ */
+/* ------------------------------------------------------------------------ */
+
+void Image::set_state_unlock()
+{
+    LifeCycleManager* lcm = Nebula::instance().get_lcm();
+
+    bool vms_notify = false;
+
+    switch (state) {
+        case LOCKED:
+            set_state(READY);
+            break;
+
+        case LOCKED_USED:
+            set_state(USED);
+            vms_notify = true;
+            break;
+
+        case Image::LOCKED_USED_PERS:
+            set_state(USED_PERS);
+            vms_notify = true;
+            break;
+
+        case Image::ERROR:
+            if (running_vms == 0)
+            {
+                set_state(READY);
+            }
+            else
+            {
+                if(is_persistent())
+                {
+                    set_state(USED_PERS);
+                }
+                else
+                {
+                    set_state(USED);
+                }
+
+                vms_notify = true;
+            }
+            break;
+
+        default:
+            break;
+    }
+
+    if ( vms_notify )
+    {
+        const set<int>& vms = vm_collection.get_collection();
+
+        for(set<int>::iterator i = vms.begin(); i != vms.end(); i++)
+        {
+            lcm->trigger(LifeCycleManager::DISK_LOCK_SUCCESS, *i);
+        }
+    }
+}
