@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------- #
-# Copyright 2002-2015, OpenNebula Project, OpenNebula Systems                #
+# Copyright 2002-2016, OpenNebula Project, OpenNebula Systems                #
 #                                                                            #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may    #
 # not use this file except in compliance with the License. You may obtain    #
@@ -33,6 +33,9 @@ module OpenNebula
     #                  ACL
     #                  SECGROUP
     #                  VDC
+    #                  VROUTER
+    #                  MARKETPLACE
+    #                  MARKETPLACEAPP
     #     RIGHTS    -> + separated list
     #                  USE
     #                  MANAGE
@@ -49,19 +52,22 @@ module OpenNebula
 
         RESOURCES =
         {
-            "VM"            =>    0x1000000000,
-            "HOST"          =>    0x2000000000,
-            "NET"           =>    0x4000000000,
-            "IMAGE"         =>    0x8000000000,
-            "USER"          =>   0x10000000000,
-            "TEMPLATE"      =>   0x20000000000,
-            "GROUP"         =>   0x40000000000,
-            "DATASTORE"     =>  0x100000000000,
-            "CLUSTER"       =>  0x200000000000,
-            "DOCUMENT"      =>  0x400000000000,
-            "ZONE"          =>  0x800000000000,
-            "SECGROUP"      => 0x1000000000000,
-            "VDC"           => 0x2000000000000
+            "VM"            =>     0x1000000000,
+            "HOST"          =>     0x2000000000,
+            "NET"           =>     0x4000000000,
+            "IMAGE"         =>     0x8000000000,
+            "USER"          =>    0x10000000000,
+            "TEMPLATE"      =>    0x20000000000,
+            "GROUP"         =>    0x40000000000,
+            "DATASTORE"     =>   0x100000000000,
+            "CLUSTER"       =>   0x200000000000,
+            "DOCUMENT"      =>   0x400000000000,
+            "ZONE"          =>   0x800000000000,
+            "SECGROUP"      =>  0x1000000000000,
+            "VDC"           =>  0x2000000000000,
+            "VROUTER"       =>  0x4000000000000,
+            "MARKETPLACE"   =>  0x8000000000000,
+            "MARKETPLACEAPP"=> 0x10000000000000
         }
 
         RIGHTS =
