@@ -1,5 +1,5 @@
 /* -------------------------------------------------------------------------- */
-/* Copyright 2002-2015, OpenNebula Project, OpenNebula Systems                */
+/* Copyright 2002-2016, OpenNebula Project, OpenNebula Systems                */
 /*                                                                            */
 /* Licensed under the Apache License, Version 2.0 (the "License"); you may    */
 /* not use this file except in compliance with the License. You may obtain    */
@@ -28,8 +28,6 @@ void ImageEnable::request_execute(xmlrpc_c::paramList const& paramList,
     bool    enable_flag = xmlrpc_c::value_boolean(paramList.getBoolean(2));
     int     rc;
 
-    string err_msg;
-
     Nebula&          nd     = Nebula::instance();
     ImageManager *   imagem = nd.get_imagem();
 
@@ -38,20 +36,20 @@ void ImageEnable::request_execute(xmlrpc_c::paramList const& paramList,
         return;
     }
 
-    rc = imagem->enable_image(id,enable_flag, err_msg);
+    rc = imagem->enable_image(id,enable_flag, att.resp_msg);
 
     if( rc < 0 )
     {
         if (enable_flag == true)
         {
-            err_msg = "Could not enable image: " + err_msg;
+            att.resp_msg = "Could not enable image: " + att.resp_msg;
         }
         else
         {
-            err_msg = "Could not disable image: " + err_msg;
+            att.resp_msg = "Could not disable image: " + att.resp_msg;
         }
 
-        failure_response(INTERNAL, request_error(err_msg,""), att);
+        failure_response(INTERNAL, att);
         return;
     }
 
@@ -66,25 +64,82 @@ void ImagePersistent::request_execute(xmlrpc_c::paramList const& paramList,
 {
     int     id              = xmlrpc_c::value_int(paramList.getInt(1));
     bool    persistent_flag = xmlrpc_c::value_boolean(paramList.getBoolean(2));
+
+    ErrorCode ec = request_execute(id, persistent_flag, att);
+
+    if ( ec == SUCCESS )
+    {
+        success_response(id, att);
+    }
+    else
+    {
+        failure_response(ec, att);
+    }
+}
+
+/* ------------------------------------------------------------------------- */
+/* ------------------------------------------------------------------------- */
+
+Request::ErrorCode ImagePersistent::request_execute(
+            int     id,
+            bool    persistent_flag,
+            RequestAttributes& att)
+{
     int     rc;
 
-    Image * image;
-    string  err_msg;
+    int ds_id;
+    int ds_persistent_only;
 
-    if ( basic_authorization(id, att) == false )
+    Nebula&  nd = Nebula::instance();
+    ImagePool *     ipool  = nd.get_ipool();
+    DatastorePool * dspool = nd.get_dspool();
+
+    Datastore * ds;
+    Image * image;
+
+    ErrorCode ec;
+
+    ec = basic_authorization(ipool, id,
+            AuthRequest::MANAGE, PoolObjectSQL::IMAGE, att);
+
+    if ( ec != SUCCESS)
     {
-        return;
+        return ec;
     }
 
-    image = static_cast<Image *>(pool->get(id,true));
+    image = ipool->get(id,true);
 
     if ( image == 0 )
     {
-        failure_response(NO_EXISTS,
-                get_error(object_name(auth_object),id),
-                att);
+        att.resp_id = id;
 
-        return;
+        return NO_EXISTS;
+    }
+
+    ds_id = image->get_ds_id();
+
+    image->unlock();
+
+    ds = dspool->get(ds_id, true);
+
+    if ( ds == 0 )
+    {
+        att.resp_msg = "Datastore no longer exists.";
+
+        return INTERNAL;
+    }
+
+    ds_persistent_only = ds->is_persistent_only();
+
+    ds->unlock();
+
+    image = ipool->get(id,true);
+
+    if ( image == 0 )
+    {
+        att.resp_id = id;
+
+        return NO_EXISTS;
     }
 
     switch (image->get_type())
@@ -97,37 +152,45 @@ void ImagePersistent::request_execute(xmlrpc_c::paramList const& paramList,
         case Image::KERNEL:
         case Image::RAMDISK:
         case Image::CONTEXT:
-            failure_response(ACTION,
-                request_error("KERNEL, RAMDISK and CONTEXT files must be "
-                "non-persistent",""), att);
+            att.resp_msg = "KERNEL, RAMDISK and CONTEXT must be non-persistent";
             image->unlock();
-        return;
+
+            return ACTION;
     }
 
-    rc = image->persistent(persistent_flag, err_msg);
+    /* Check if datastore allows the operation */
+    if ( ds_persistent_only && persistent_flag == false )
+    {
+        att.resp_msg = "This Datastore only accepts persistent images.";
+
+        image->unlock();
+
+        return INTERNAL;
+    }
+
+    rc = image->persistent(persistent_flag, att.resp_msg);
 
     if ( rc != 0  )
     {
         if (persistent_flag == true)
         {
-            err_msg = "Could not make image persistent: " + err_msg;
+            att.resp_msg = "Could not make image persistent: " + att.resp_msg;
         }
         else
         {
-            err_msg = "Could not make image non-persistent: " + err_msg;
+            att.resp_msg = "Could not make image non-persistent: " + att.resp_msg;
         }
 
-        failure_response(INTERNAL,request_error(err_msg,""), att);
-
         image->unlock();
-        return;
+
+        return INTERNAL;
     }
 
-    pool->update(image);
+    ipool->update(image);
 
     image->unlock();
 
-    success_response(id, att);
+    return SUCCESS;
 }
 
 /* ------------------------------------------------------------------------- */
@@ -143,7 +206,6 @@ void ImageChangeType::request_execute(xmlrpc_c::paramList const& paramList,
     Image::ImageType itype;
 
     Image * image;
-    string  err_msg;
 
     if ( basic_authorization(id, att) == false )
     {
@@ -154,10 +216,8 @@ void ImageChangeType::request_execute(xmlrpc_c::paramList const& paramList,
 
     if ( image == 0 )
     {
-        failure_response(NO_EXISTS,
-                get_error(object_name(auth_object),id),
-                att);
-
+        att.resp_id = id;
+        failure_response(NO_EXISTS, att);
         return;
     }
 
@@ -168,14 +228,12 @@ void ImageChangeType::request_execute(xmlrpc_c::paramList const& paramList,
         case Image::OS:
         case Image::DATABLOCK:
         case Image::CDROM:
-            if ((itype != Image::OS) &&
-                (itype != Image::DATABLOCK)&&
-                (itype != Image::CDROM) )
+            if ((itype != Image::OS) && (itype != Image::DATABLOCK)&&
+                (itype != Image::CDROM))
             {
-                failure_response(ACTION,
-                    request_error("Cannot change image type to an incompatible"
-                        " type for the current datastore.",""),
-                    att);
+                att.resp_msg = "Cannot change image type to an incompatible type"
+                    " for the current datastore.";
+                failure_response(ACTION, att);
 
                 image->unlock();
                 return;
@@ -189,10 +247,9 @@ void ImageChangeType::request_execute(xmlrpc_c::paramList const& paramList,
                 (itype != Image::RAMDISK)&&
                 (itype != Image::CONTEXT) )
             {
-                failure_response(ACTION,
-                    request_error("Cannot change image type to an incompatible"
-                        " type for the current datastore.",""),
-                    att);
+                att.resp_msg = "Cannot change image type to an incompatible type"
+                    " for the current datastore.";
+                failure_response(ACTION, att);
 
                 image->unlock();
                 return;
@@ -200,11 +257,11 @@ void ImageChangeType::request_execute(xmlrpc_c::paramList const& paramList,
         break;
     }
 
-    rc = image->set_type(type, err_msg);
+    rc = image->set_type(type, att.resp_msg);
 
     if ( rc != 0  )
     {
-        failure_response(INTERNAL,request_error(err_msg,""), att);
+        failure_response(INTERNAL, att);
 
         image->unlock();
         return;
@@ -227,9 +284,40 @@ void ImageClone::request_execute(
     int    clone_id = xmlrpc_c::value_int(paramList.getInt(1));
     string name     = xmlrpc_c::value_string(paramList.getString(2));
 
+    int new_id;
+
+    int ds_id = -1;
+
+    if (paramList.size() > 3)
+    {
+        ds_id = xmlrpc_c::value_int(paramList.getInt(3));
+    }
+
+    ErrorCode ec = request_execute(clone_id, name, ds_id, new_id, att);
+
+    if ( ec == SUCCESS )
+    {
+        success_response(new_id, att);
+    }
+    else
+    {
+        failure_response(ec, att);
+    }
+}
+
+/* -------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
+
+Request::ErrorCode ImageClone::request_execute(
+        int             clone_id,
+        const string&   name,
+        int             ds_id,
+        int             &new_id,
+        RequestAttributes& att)
+{
     long long       avail, size;
-    int             rc, new_id, ds_id_orig, ds_id = -1;
-    string          error_str, ds_name, ds_data, ds_mad;
+    int             rc, ds_id_orig;
+    string          ds_name, ds_data, ds_mad, tm_mad;
     bool            ds_check;
 
     Image::DiskType disk_type;
@@ -243,12 +331,7 @@ void ImageClone::request_execute(
     Nebula&  nd = Nebula::instance();
 
     DatastorePool * dspool = nd.get_dspool();
-    ImagePool *     ipool  = static_cast<ImagePool *>(pool);
-
-    if (paramList.size() > 3)
-    {
-        ds_id = xmlrpc_c::value_int(paramList.getInt(3));
-    }
+    ImagePool *     ipool  = nd.get_ipool();
 
     // ------------------------- Get source Image info -------------------------
 
@@ -256,11 +339,8 @@ void ImageClone::request_execute(
 
     if ( img == 0 )
     {
-        failure_response(NO_EXISTS,
-                get_error(object_name(auth_object), clone_id),
-                att);
-
-        return;
+        att.resp_id = clone_id;
+        return NO_EXISTS;
     }
 
     switch (img->get_type())
@@ -273,21 +353,18 @@ void ImageClone::request_execute(
         case Image::KERNEL:
         case Image::RAMDISK:
         case Image::CONTEXT:
-            failure_response(ACTION,
-                allocate_error("KERNEL, RAMDISK and CONTEXT files cannot be "
-                    "cloned."), att);
+            att.resp_msg = "KERNEL, RAMDISK and CONTEXT cannot be cloned.";
             img->unlock();
-        return;
+        return ACTION;
     }
 
     const Snapshots& snaps = img->get_snapshots();
 
     if (snaps.size () > 0)
     {
-        failure_response(ACTION,
-                request_error("Cannot clone images with snapshots",""), att);
+        att.resp_msg = "Cannot clone images with snapshots";
         img->unlock();
-        return;
+        return ACTION;
     }
 
     tmpl = img->clone_template(name);
@@ -311,23 +388,21 @@ void ImageClone::request_execute(
 
     if ( ds == 0 )
     {
-        failure_response(NO_EXISTS,
-                get_error(object_name(PoolObjectSQL::DATASTORE), ds_id),
-                att);
+        att.resp_obj = PoolObjectSQL::DATASTORE;
+        att.resp_id  = ds_id;
 
         delete tmpl;
-        return;
+        return NO_EXISTS;
     }
 
     if ( ds->get_type() != Datastore::IMAGE_DS )
     {
-        failure_response(ACTION,
-            request_error("Clone only supported for IMAGE_DS Datastores",""),att);
+        att.resp_msg = "Clone only supported for IMAGE_DS Datastores";
 
         ds->unlock();
 
         delete tmpl;
-        return;
+        return ACTION;
     }
 
     ds->get_permissions(ds_perms);
@@ -339,6 +414,7 @@ void ImageClone::request_execute(
     ds_check = ds->get_avail_mb(avail);
     ds_name  = ds->get_name();
     ds_mad   = ds->get_ds_mad();
+    tm_mad   = ds->get_tm_mad();
 
     ds->unlock();
 
@@ -348,33 +424,31 @@ void ImageClone::request_execute(
 
         if (ds == 0)
         {
-            failure_response(NO_EXISTS,
-                get_error(object_name(PoolObjectSQL::DATASTORE),ds_id_orig),att);
+            att.resp_obj = PoolObjectSQL::DATASTORE;
+            att.resp_id  = ds_id_orig;
 
             delete tmpl;
-            return;
+            return NO_EXISTS;
         }
 
         if (ds->get_type() != Datastore::IMAGE_DS)
         {
-            failure_response(ACTION, request_error(
-                "Clone only supported for IMAGE_DS Datastores",""), att);
+            att.resp_msg = "Clone only supported for IMAGE_DS Datastores";
 
             ds->unlock();
 
             delete tmpl;
-            return;
+            return ACTION;
         }
 
         if (ds->get_ds_mad() != ds_mad)
         {
-            failure_response(ACTION, request_error(
-                "Clone only supported to same DS_MAD Datastores",""), att);
+            att.resp_msg = "Clone only supported to same DS_MAD Datastores";
 
             ds->unlock();
 
             delete tmpl;
-            return;
+            return ACTION;
         }
 
         ds->get_permissions(ds_perms_orig);
@@ -389,11 +463,10 @@ void ImageClone::request_execute(
 
     if (ds_check && (size > avail))
     {
-        failure_response(ACTION,
-            request_error("Not enough space in datastore",""), att);
+        att.resp_msg = "Not enough space in datastore";
 
         delete tmpl;
-        return;
+        return ACTION;
     }
 
     if ( att.uid != 0 )
@@ -402,34 +475,38 @@ void ImageClone::request_execute(
         string      tmpl_str;
 
         // ------------------ Check permissions and ACLs  ----------------------
-
+        // Create image
+        // Use original image
+        // Use target datastore
+        // Use original datastore, if different
+        // ---------------------------------------------------------------------
         tmpl->to_xml(tmpl_str);
 
-        ar.add_create_auth(att.uid, att.gid, auth_object, tmpl_str); // CREATE IMAGE
+        ar.add_create_auth(att.uid, att.gid, PoolObjectSQL::IMAGE, tmpl_str);
 
-        ar.add_auth(AuthRequest::USE, ds_perms); // USE DATASTORE
+        ar.add_auth(AuthRequest::USE, perms);
 
-        if (ds_id != ds_id_orig) // USE (original) DATASTORE
+        ar.add_auth(AuthRequest::USE, ds_perms);
+
+        if (ds_id != ds_id_orig)
         {
-            ar.add_auth(AuthRequest::USE, ds_perms_orig); // USE DATASTORE
+            ar.add_auth(AuthRequest::USE, ds_perms_orig);
         }
 
         if (UserPool::authorize(ar) == -1)
         {
-            failure_response(AUTHORIZATION,
-                    authorization_error(ar.message, att),
-                    att);
+            att.resp_msg = ar.message;
 
             delete tmpl;
-            return;
+            return AUTHORIZATION;
         }
 
         // -------------------------- Check Quotas  ----------------------------
 
-        if ( quota_authorization(&img_usage, Quotas::DATASTORE, att) == false )
+        if ( quota_authorization(&img_usage, Quotas::DATASTORE, att, att.resp_msg) == false )
         {
             delete tmpl;
-            return;
+            return AUTHORIZATION;
         }
     }
 
@@ -444,15 +521,17 @@ void ImageClone::request_execute(
                          disk_type,
                          ds_data,
                          Datastore::IMAGE_DS,
+                         ds_mad,
+                         tm_mad,
+                         "",
                          clone_id,
                          &new_id,
-                         error_str);
+                         att.resp_msg);
     if ( rc < 0 )
     {
         quota_rollback(&img_usage, Quotas::DATASTORE, att);
 
-        failure_response(INTERNAL, allocate_error(error_str), att);
-        return;
+        return ALLOCATE;
     }
 
     ds = dspool->get(ds_id, true);
@@ -466,7 +545,7 @@ void ImageClone::request_execute(
         ds->unlock();
     }
 
-    success_response(new_id, att);
+    return SUCCESS;
 }
 
 /* ------------------------------------------------------------------------- */
@@ -486,12 +565,11 @@ void ImageSnapshotDelete::request_execute(xmlrpc_c::paramList const& paramList,
         return;
     }
 
-    string err_msg;
-    int    rc = imagem->delete_snapshot(id, snap_id, err_msg);
+    int rc = imagem->delete_snapshot(id, snap_id, att.resp_msg);
 
     if ( rc < 0 )
     {
-        failure_response(ACTION, request_error(err_msg, ""), att);
+        failure_response(ACTION, att);
         return;
     }
 
@@ -515,12 +593,11 @@ void ImageSnapshotRevert::request_execute(xmlrpc_c::paramList const& paramList,
         return;
     }
 
-    string err_msg;
-    int    rc = imagem->revert_snapshot(id, snap_id, err_msg);
+    int rc = imagem->revert_snapshot(id, snap_id, att.resp_msg);
 
     if ( rc < 0 )
     {
-        failure_response(ACTION, request_error(err_msg, ""), att);
+        failure_response(ACTION, att);
         return;
     }
 
@@ -544,12 +621,11 @@ void ImageSnapshotFlatten::request_execute(xmlrpc_c::paramList const& paramList,
         return;
     }
 
-    string err_msg;
-    int    rc = imagem->flatten_snapshot(id, snap_id, err_msg);
+    int rc = imagem->flatten_snapshot(id, snap_id, att.resp_msg);
 
     if ( rc < 0 )
     {
-        failure_response(ACTION, request_error(err_msg, ""), att);
+        failure_response(ACTION, att);
         return;
     }
 
