@@ -1,5 +1,5 @@
 /* -------------------------------------------------------------------------- */
-/* Copyright 2002-2015, OpenNebula Project, OpenNebula Systems                */
+/* Copyright 2002-2016, OpenNebula Project, OpenNebula Systems                */
 /*                                                                            */
 /* Licensed under the Apache License, Version 2.0 (the "License"); you may    */
 /* not use this file except in compliance with the License. You may obtain    */
@@ -31,15 +31,14 @@ void RequestManagerRename::request_execute(xmlrpc_c::paramList const& paramList,
 
     int    rc;
     string old_name;
-    string error_str;
 
     PoolObjectAuth  operms;
     PoolObjectSQL * object;
 
     if (test_and_set_rename(oid) == false)
     {
-        failure_response(INTERNAL,
-            request_error("Object is being renamed", ""), att);
+        att.resp_msg = "Object is being renamed";
+        failure_response(INTERNAL, att);
 
         return;
     }
@@ -70,9 +69,8 @@ void RequestManagerRename::request_execute(xmlrpc_c::paramList const& paramList,
 
         if (UserPool::authorize(ar) == -1)
         {
-            failure_response(AUTHORIZATION,
-                             authorization_error(ar.message, att),
-                             att);
+            att.resp_msg = ar.message;
+            failure_response(AUTHORIZATION, att);
             clear_rename(oid);
             return;
         }
@@ -89,13 +87,13 @@ void RequestManagerRename::request_execute(xmlrpc_c::paramList const& paramList,
 
         object->unlock();
 
-        oss << PoolObjectSQL::type_to_str(auth_object)
-            << " cannot be renamed to " << new_name
-            << " because it collides with "
-            << PoolObjectSQL::type_to_str(auth_object) << " "
+        oss << object_name(auth_object) << " cannot be renamed to " << new_name
+            << " because it collides with " << object_name(auth_object) << " "
             << id;
 
-        failure_response(ACTION, request_error(oss.str(), ""), att);
+        att.resp_msg = oss.str();
+
+        failure_response(ACTION, att);
 
         clear_rename(oid);
         return;
@@ -107,19 +105,18 @@ void RequestManagerRename::request_execute(xmlrpc_c::paramList const& paramList,
 
     if ( object == 0 )
     {
-        failure_response(NO_EXISTS,
-                         get_error(object_name(auth_object), oid),
-                         att);
+        att.resp_id = oid;
+        failure_response(NO_EXISTS, att);
 
         clear_rename(oid);
         return;
     }
 
-    if ( object->set_name(new_name, error_str) != 0 )
+    if ( object->set_name(new_name, att.resp_msg) != 0 )
     {
         object->unlock();
 
-        failure_response(ACTION, request_error(error_str, ""), att);
+        failure_response(ACTION, att);
 
         clear_rename(oid);
         return;
@@ -152,26 +149,16 @@ void ClusterRename::batch_rename(int oid)
         return;
     }
 
-    const set<int> & hosts      = cluster->get_host_ids();
-    const set<int> & datastores = cluster->get_datastore_ids();
-    const set<int> & vnets      = cluster->get_vnet_ids();
+    const set<int> & hosts = cluster->get_host_ids();
 
-    set<int>::iterator it;
-
-    string cluster_name = cluster->get_name();
+    string cluster_name    = cluster->get_name();
 
     cluster->unlock();
 
     Host *              host;
     HostPool*           hpool = Nebula::instance().get_hpool();
 
-    Datastore *         ds;
-    DatastorePool*      dspool = Nebula::instance().get_dspool();
-
-    VirtualNetwork*     vnet;
-    VirtualNetworkPool* vnpool = Nebula::instance().get_vnpool();
-
-    for (it = hosts.begin(); it != hosts.end(); it++)
+    for (set<int>::iterator it = hosts.begin(); it != hosts.end(); it++)
     {
         host = hpool->get(*it, true);
 
@@ -186,38 +173,6 @@ void ClusterRename::batch_rename(int oid)
             host->unlock();
         }
     }
-
-    for (it = datastores.begin(); it != datastores.end(); it++)
-    {
-        ds = dspool->get(*it, true);
-
-        if (ds != 0)
-        {
-            if (ds->get_cluster_id() == oid)
-            {
-                ds->set_cluster(oid, cluster_name);
-                dspool->update(ds);
-            }
-
-            ds->unlock();
-        }
-    }
-
-    for (it = vnets.begin(); it != vnets.end(); it++)
-    {
-        vnet = vnpool->get(*it, true);
-
-        if (vnet != 0)
-        {
-            if (vnet->get_cluster_id() == oid)
-            {
-                vnet->set_cluster(oid, cluster_name);
-                vnpool->update(vnet);
-            }
-
-            vnet->unlock();
-        }
-    }
 }
 
 /* -------------------------------------------------------------------------- */
@@ -302,3 +257,41 @@ void HostRename::batch_rename(int oid)
 
 /* -------------------------------------------------------------------------- */
 /* -------------------------------------------------------------------------- */
+
+void MarketPlaceRename::batch_rename(int oid)
+{
+    MarketPlace * market = static_cast<MarketPlacePool*>(pool)->get(oid, true);
+
+    if (market == 0)
+    {
+        return;
+    }
+
+    const std::set<int> & apps = market->get_marketapp_ids();
+
+    std::set<int>::iterator it;
+
+    std::string market_name = market->get_name();
+
+    market->unlock();
+
+    MarketPlaceApp *     app;
+    MarketPlaceAppPool * apppool = Nebula::instance().get_apppool();
+
+    for (it = apps.begin(); it != apps.end(); it++)
+    {
+        app = apppool->get(*it, true);
+
+        if (app != 0)
+        {
+            if (app->get_market_id() == oid)
+            {
+                app->set_market_name(market_name);
+                apppool->update(app);
+            }
+
+            app->unlock();
+        }
+    }
+}
+
