@@ -1,5 +1,5 @@
 /* -------------------------------------------------------------------------- */
-/* Copyright 2002-2015, OpenNebula Project, OpenNebula Systems                */
+/* Copyright 2002-2016, OpenNebula Project, OpenNebula Systems                */
 /*                                                                            */
 /* Licensed under the Apache License, Version 2.0 (the "License"); you may    */
 /* not use this file except in compliance with the License. You may obtain    */
@@ -108,7 +108,6 @@ void Scheduler::start()
 
     string etc_path;
 
-    int          oned_port;
     unsigned int live_rescheds;
 
     pthread_attr_t pattr;
@@ -143,11 +142,7 @@ void Scheduler::start()
         throw runtime_error("Error reading configuration file.");
     }
 
-    conf.get("ONED_PORT", oned_port);
-
-    oss.str("");
-    oss << "http://localhost:" << oned_port << "/RPC2";
-    url = oss.str();
+    conf.get("ONE_XMLRPC", one_xmlrpc);
 
     conf.get("SCHED_INTERVAL", timer);
 
@@ -165,21 +160,16 @@ void Scheduler::start()
 
     try
     {
-        vector<const Attribute *> logs;
-        int rc;
-
         NebulaLog::LogType log_system = NebulaLog::UNDEFINED;
         Log::MessageType   clevel     = Log::ERROR;;
 
-        rc = conf.get("LOG", logs);
+        const VectorAttribute * log = conf.get("LOG");
 
-        if ( rc != 0 )
+        if ( log != 0 )
         {
             string value;
             int    ilevel;
 
-            const VectorAttribute * log = static_cast<const VectorAttribute *>
-                                                          (logs[0]);
             value      = log->vector_value("SYSTEM");
             log_system = NebulaLog::str_to_type(value);
 
@@ -230,15 +220,18 @@ void Scheduler::start()
 
     try
     {
-        long long message_size;
+        long long    message_size;
+        unsigned int timeout;
 
         conf.get("MESSAGE_SIZE", message_size);
 
-        client = new Client("", url, message_size);
+        conf.get("TIMEOUT", timeout);
+
+        Client::initialize("", one_xmlrpc, message_size, timeout);
 
         oss.str("");
 
-        oss << "XML-RPC client using " << client->get_message_size()
+        oss << "XML-RPC client using " << (Client::client())->get_message_size()
             << " bytes for response buffer.\n";
 
         NebulaLog::log("SCHED", Log::INFO, oss);
@@ -259,15 +252,13 @@ void Scheduler::start()
         try
         {
             xmlrpc_c::value result;
+            vector<xmlrpc_c::value> values;
 
-            client->call(client->get_endpoint(),        // serverUrl
-                         "one.system.config",           // methodName
-                         "s",                           // arguments format
-                         &result,                       // resultP
-                         client->get_oneauth().c_str());// auth string
+            Client * client = Client::client();
 
-            vector<xmlrpc_c::value> values =
-                            xmlrpc_c::value_array(result).vectorValueValue();
+            client->call("one.system.config", "", &result);
+
+            values = xmlrpc_c::value_array(result).vectorValueValue();
 
             bool   success = xmlrpc_c::value_boolean(values[0]);
             string message = xmlrpc_c::value_string(values[1]);
@@ -297,15 +288,13 @@ void Scheduler::start()
 
     NebulaLog::log("SCHED", Log::INFO, "oned successfully contacted.");
 
-    vector<const Attribute*> fed;
-
     zone_id = 0;
 
-    if (oned_conf.get("FEDERATION", fed) > 0)
-    {
-        const VectorAttribute * va=static_cast<const VectorAttribute *>(fed[0]);
+    const VectorAttribute * fed = oned_conf.get("FEDERATION");
 
-        if (va->vector_value("ZONE_ID", zone_id) != 0)
+    if (fed != 0)
+    {
+        if (fed->vector_value("ZONE_ID", zone_id) != 0)
         {
             zone_id = 0;
         }
@@ -320,16 +309,18 @@ void Scheduler::start()
     // Pools
     // -------------------------------------------------------------------------
 
-    hpool  = new HostPoolXML(client);
-    clpool = new ClusterPoolXML(client);
-    vmpool = new VirtualMachinePoolXML(client,machines_limit,(live_rescheds==1));
+    hpool  = new HostPoolXML(Client::client());
+    upool  = new UserPoolXML(Client::client());
+    clpool = new ClusterPoolXML(Client::client());
+    vmpool = new VirtualMachinePoolXML(Client::client(), machines_limit,
+            live_rescheds==1);
 
-    vmapool = new VirtualMachineActionsPoolXML(client, machines_limit);
+    vmapool = new VirtualMachineActionsPoolXML(Client::client(), machines_limit);
 
-    dspool     = new SystemDatastorePoolXML(client);
-    img_dspool = new ImageDatastorePoolXML(client);
+    dspool     = new SystemDatastorePoolXML(Client::client());
+    img_dspool = new ImageDatastorePoolXML(Client::client());
 
-    acls = new AclXML(client, zone_id);
+    acls = new AclXML(Client::client(), zone_id);
 
     // -----------------------------------------------------------
     // Load scheduler policies
@@ -430,8 +421,6 @@ int Scheduler::set_up_pools()
     //Cleans the cache and get the datastores
     //--------------------------------------------------------------------------
 
-    // TODO: Avoid two ds pool info calls to oned
-
     rc = dspool->set_up();
 
     if ( rc != 0 )
@@ -450,6 +439,17 @@ int Scheduler::set_up_pools()
     //Cleans the cache and get the hosts ids
     //--------------------------------------------------------------------------
 
+    rc = upool->set_up();
+
+    if ( rc != 0 )
+    {
+        return rc;
+    }
+
+    //--------------------------------------------------------------------------
+    //Cleans the cache and get the hosts ids
+    //--------------------------------------------------------------------------
+
     rc = hpool->set_up();
 
     if ( rc != 0 )
@@ -499,6 +499,8 @@ int Scheduler::set_up_pools()
  *    2. Meets user/policy requirements
  *    3. Have enough capacity to host the VM
  *
+ *  @param acl pool
+ *  @param users the user pool
  *  @param vm the virtual machine
  *  @param vm_memory vm requirement
  *  @param vm_cpu vm requirement
@@ -511,9 +513,9 @@ int Scheduler::set_up_pools()
  *  @param error, string describing why the host is not valid
  *  @return true for a positive match
  */
-static bool match_host(AclXML * acls, VirtualMachineXML* vm, int vmem, int vcpu,
-    vector<Attribute *>& vpci, HostXML * host, int &n_auth, int& n_error,
-    int &n_fits, int &n_matched, string &error)
+static bool match_host(AclXML * acls, UserPoolXML * upool, VirtualMachineXML* vm,
+    int vmem, int vcpu, vector<VectorAttribute *>& vpci, HostXML * host,
+    int &n_auth, int& n_error, int &n_fits, int &n_matched, string &error)
 {
     // -------------------------------------------------------------------------
     // Filter current Hosts for resched VMs
@@ -540,14 +542,19 @@ static bool match_host(AclXML * acls, VirtualMachineXML* vm, int vmem, int vcpu,
     {
         PoolObjectAuth hperms;
 
-        hperms.oid      = host->get_hid();
-        hperms.cid      = host->get_cid();
-        hperms.obj_type = PoolObjectSQL::HOST;
+        host->get_permissions(hperms);
 
-        // Only include the VM group ID
+        UserXML * user = upool->get(vm->get_uid());
 
-        set<int> gids;
-        gids.insert(vm->get_gid());
+        if (user == 0)
+        {
+            error = "User does not exists.";
+            return false;
+        }
+
+        const vector<int> vgids = user->get_gids();
+
+        set<int> gids(vgids.begin(), vgids.end());
 
         if ( !acls->authorize(vm->get_uid(), gids, hperms, AuthRequest::MANAGE))
         {
@@ -614,6 +621,8 @@ static bool match_host(AclXML * acls, VirtualMachineXML* vm, int vmem, int vcpu,
  *    1. Meet user/policy requirements
  *    2. Have enough capacity to host the VM
  *
+ *  @param acl pool
+ *  @param users the user pool
  *  @param vm the virtual machine
  *  @param vdisk vm requirement
  *  @param ds to evaluate vm assgiment
@@ -624,9 +633,9 @@ static bool match_host(AclXML * acls, VirtualMachineXML* vm, int vmem, int vcpu,
  *  @param error, string describing why the host is not valid
  *  @return true for a positive match
  */
-static bool match_system_ds(AclXML * acls, VirtualMachineXML* vm, long long vdisk,
-    DatastoreXML * ds, int& n_auth, int& n_error, int& n_fits, int &n_matched,
-    string &error)
+static bool match_system_ds(AclXML * acls, UserPoolXML * upool,
+    VirtualMachineXML* vm, long long vdisk, DatastoreXML * ds, int& n_auth,
+    int& n_error, int& n_fits, int &n_matched, string &error)
 {
     // -------------------------------------------------------------------------
     // Check if user is authorized
@@ -637,10 +646,17 @@ static bool match_system_ds(AclXML * acls, VirtualMachineXML* vm, long long vdis
 
         ds->get_permissions(dsperms);
 
-        // Only include the VM group ID
+        UserXML * user = upool->get(vm->get_uid());
 
-        set<int> gids;
-        gids.insert(vm->get_gid());
+        if (user == 0)
+        {
+            error = "User does not exists.";
+            return false;
+        }
+
+        const vector<int> vgids = user->get_gids();
+
+        set<int> gids(vgids.begin(), vgids.end());
 
         if ( !acls->authorize(vm->get_uid(), gids, dsperms, AuthRequest::USE))
         {
@@ -679,11 +695,15 @@ static bool match_system_ds(AclXML * acls, VirtualMachineXML* vm, long long vdis
             n_error++;
 
             oss << "Error in SCHED_DS_REQUIREMENTS: '"
-                << vm->get_ds_requirements() << "', error: " << error;
+                << vm->get_ds_requirements() << "', error: " << estr;
 
             vm->log(oss.str());
 
+            error = oss.str();
+
             free(estr);
+
+            return false;
         }
 
         if (matched == false)
@@ -719,7 +739,7 @@ void Scheduler::match_schedule()
     int vm_memory;
     int vm_cpu;
     long long vm_disk;
-    vector<Attribute *> vm_pci;
+    vector<VectorAttribute *> vm_pci;
 
     int n_resources;
     int n_matched;
@@ -733,16 +753,20 @@ void Scheduler::match_schedule()
     string m_error;
 
     map<int, ObjectXML*>::const_iterator  vm_it;
-    map<int, ObjectXML*>::const_iterator  h_it;
+    map<int, ObjectXML*>::const_iterator  obj_it;
 
     vector<SchedulerPolicy *>::iterator it;
 
     const map<int, ObjectXML*> pending_vms = vmpool->get_objects();
     const map<int, ObjectXML*> hosts       = hpool->get_objects();
     const map<int, ObjectXML*> datastores  = dspool->get_objects();
+    const map<int, ObjectXML*> users       = upool->get_objects();
 
-    double total_match_time = 0;
-    double total_rank_time = 0;
+    double total_cl_match_time = 0;
+    double total_host_match_time = 0;
+    double total_host_rank_time = 0;
+    double total_ds_match_time = 0;
+    double total_ds_rank_time = 0;
 
     time_t stime = time(0);
 
@@ -786,12 +810,12 @@ void Scheduler::match_schedule()
         // ---------------------------------------------------------------------
         profile(true);
 
-        for (h_it=hosts.begin(); h_it != hosts.end(); h_it++)
+        for (obj_it=hosts.begin(); obj_it != hosts.end(); obj_it++)
         {
-            host = static_cast<HostXML *>(h_it->second);
+            host = static_cast<HostXML *>(obj_it->second);
 
-            if (match_host(acls, vm, vm_memory, vm_cpu, vm_pci, host, n_auth,
-                    n_error, n_fits, n_matched, m_error))
+            if (match_host(acls, upool, vm, vm_memory, vm_cpu, vm_pci, host,
+                    n_auth, n_error, n_fits, n_matched, m_error))
             {
                 vm->add_match_host(host->get_hid());
 
@@ -815,7 +839,7 @@ void Scheduler::match_schedule()
             }
         }
 
-        total_match_time += profile(false);
+        total_host_match_time += profile(false);
 
         // ---------------------------------------------------------------------
         // Log scheduling errors to VM user if any
@@ -871,7 +895,7 @@ void Scheduler::match_schedule()
 
         vm->sort_match_hosts();
 
-        total_rank_time += profile(false);
+        total_host_rank_time += profile(false);
 
         if (vm->is_resched())//Will use same system DS for migrations
         {
@@ -884,18 +908,20 @@ void Scheduler::match_schedule()
         // Match datastores for this VM
         // ---------------------------------------------------------------------
 
+        profile(true);
+
         n_resources = 0;
         n_auth    = 0;
         n_matched = 0;
         n_error   = 0;
         n_fits    = 0;
 
-        for (h_it=datastores.begin(); h_it != datastores.end(); h_it++)
+        for (obj_it=datastores.begin(); obj_it != datastores.end(); obj_it++)
         {
-            ds = static_cast<DatastoreXML *>(h_it->second);
+            ds = static_cast<DatastoreXML *>(obj_it->second);
 
-            if (match_system_ds(acls, vm, vm_disk, ds, n_auth, n_error, n_fits,
-                        n_matched, m_error))
+            if (match_system_ds(acls, upool, vm, vm_disk, ds, n_auth, n_error,
+                        n_fits, n_matched, m_error))
             {
                 vm->add_match_datastore(ds->get_oid());
 
@@ -919,6 +945,8 @@ void Scheduler::match_schedule()
             }
         }
 
+        total_ds_match_time += profile(false);
+
         // ---------------------------------------------------------------------
         // Log scheduling errors to VM user if any
         // ---------------------------------------------------------------------
@@ -977,23 +1005,33 @@ void Scheduler::match_schedule()
         // Schedule matched datastores
         // ---------------------------------------------------------------------
 
+        profile(true);
+
         for (it=ds_policies.begin() ; it != ds_policies.end() ; it++)
         {
             (*it)->schedule(vm);
         }
 
         vm->sort_match_datastores();
+
+        total_ds_rank_time += profile(false);
     }
 
-    ostringstream oss;
+    if (NebulaLog::log_level() >= Log::DDEBUG)
+    {
+        ostringstream oss;
 
-    oss << "Match Making statistics:\n"
-        << "\tNumber of VMs: \t\t" << pending_vms.size() << endl
-        << "\tTotal time: \t\t" << one_util::float_to_str(time(0) - stime) << "s" << endl
-        << "\tTotal Match time: \t" << one_util::float_to_str(total_match_time) << "s" << endl
-        << "\tTotal Ranking time: \t" << one_util::float_to_str(total_rank_time) << "s";
+        oss << "Match Making statistics:\n"
+            << "\tNumber of VMs:            " << pending_vms.size() << endl
+            << "\tTotal time:               " << one_util::float_to_str(time(0) - stime) << "s" << endl
+            << "\tTotal Cluster Match time: " << one_util::float_to_str(total_cl_match_time) << "s" << endl
+            << "\tTotal Host Match time:    " << one_util::float_to_str(total_host_match_time) << "s" << endl
+            << "\tTotal Host Ranking time:  " << one_util::float_to_str(total_host_rank_time) << "s" << endl
+            << "\tTotal DS Match time:      " << one_util::float_to_str(total_ds_match_time) << "s" << endl
+            << "\tTotal DS Ranking time:    " << one_util::float_to_str(total_ds_rank_time) << "s" << endl;
 
-    NebulaLog::log("SCHED", Log::DDEBUG, oss);
+        NebulaLog::log("SCHED", Log::DDEBUG, oss);
+    }
 
     if (NebulaLog::log_level() >= Log::DDDEBUG)
     {
@@ -1026,7 +1064,7 @@ void Scheduler::dispatch()
 
     int cpu, mem;
     long long dsk;
-    vector<Attribute *> pci;
+    vector<VectorAttribute *> pci;
 
     int hid, dsid, cid;
     bool test_cap_result;
@@ -1148,7 +1186,7 @@ void Scheduler::dispatch()
                 //--------------------------------------------------------------
                 // Test cluster membership for datastore and selected host
                 //--------------------------------------------------------------
-                if (ds->get_cid() != cid)
+                if (!ds->is_in_cluster(cid))
                 {
                     continue;
                 }
