@@ -23,6 +23,9 @@ define(function(require) {
   Foundation.DropdownMenu.defaults.closeOnClick = true;
   Foundation.DropdownMenu.defaults.disableHover = true;
   Foundation.DropdownMenu.defaults.clickOpen = true;
+  Foundation.Reveal.defaults.closeOnClick = false;
+
+  _setupDataTableSearch();
 
   var DASHBOARD_TAB_ID = require('tabs/dashboard-tab/tabId');
   var SETTINGS_TAB_ID = require('tabs/settings-tab/tabId');
@@ -66,11 +69,11 @@ define(function(require) {
 
     if (Config.isTabEnabled(PROVISION_TAB_ID)) {
       Sunstone.showTab(PROVISION_TAB_ID);
-      $('#loading').hide();
     } else if (Config.isTabEnabled(DASHBOARD_TAB_ID)) {
       Sunstone.showTab(DASHBOARD_TAB_ID);
-      $('#loading').hide();
     }
+
+    $('#loading').hide();
   });
 
   function _setupCloseDropdownsOnClick() {
@@ -121,8 +124,16 @@ define(function(require) {
         success: function (request, obj_list) {
           $('.zone-ul').empty();
           $.each(obj_list, function() {
+            var icon;
+
+            if(this.ZONE.NAME == config['zone_name']){
+              icon = '<i class="fa fa-fw fa-check"></i>'
+            } else {
+              icon = '<i class="fa fa-fw"></i>'
+            }
+
             $('.zone-ul').append('<li>' +
-              '<a href="#" id="' + this.ZONE.NAME + '" class="zone-choice">' + this.ZONE.NAME + '</a></li>');
+              '<a href="#" id="' + this.ZONE.NAME + '" class="zone-choice">' + icon + ' ' + this.ZONE.NAME + '</a></li>');
           });
         },
         error: Notifier.onError
@@ -166,4 +177,25 @@ define(function(require) {
       Sunstone.showTab(SETTINGS_TAB_ID);
     });
   }
+
+  function _setupDataTableSearch() {
+    $.fn.dataTable.ext.type.order['file-size-pre'] = function ( data ) {
+      var matches = data.match( /^(\d+(?:\.\d+)?)\s*([a-z]+)/i );
+      var multipliers = {
+        B:  1,
+        KB: 1024,
+        MB: 1048576,
+        GB: 1073741824,
+        TB: 1099511627776,
+        PB: 1125899906842624
+      };
+
+      if (matches) {
+        var multiplier = multipliers[matches[2]];
+        return parseFloat( matches[1] ) * multiplier;
+      } else {
+        return -1;
+      }
+    }
+  }
 });
