@@ -20,6 +20,8 @@ define(function(require) {
       OpenNebulaError  = require('./error');
       Locale = require('utils/locale');
 
+  var OpenNebulaCluster = require('./cluster');
+
   var RESOURCE = "VM";
 
   var STATES_STR = [
@@ -267,6 +269,7 @@ define(function(require) {
     'GUEST_IP',
     'GUEST_IP_ADDRESSES',
     'AWS_IP_ADDRESS',
+    'AWS_PRIVATE_IP_ADDRESS',
     'AZ_IPADDRESS',
     'SL_PRIMARYIPADDRESS'
   ];
@@ -574,6 +577,18 @@ define(function(require) {
 
       return hostname;
     },
+    "clusterStr": function(element) {
+      var state = element.STATE;
+      var cluster = "--";
+      if (state == STATES.ACTIVE || state == STATES.SUSPENDED || state == STATES.POWEROFF) {
+        var history = retrieveLastHistoryRecord(element)
+        if (history) {
+          cluster = history.CID;
+        };
+      };
+
+      return OpenNebulaCluster.getName(cluster);
+    },
     "migrateActionStr": function(stateId) {
       return MIGRATE_ACTION_STR[stateId];
     },
@@ -660,6 +675,7 @@ define(function(require) {
   function ipsStr(element, divider) {
     var divider = divider || "<br>"
     var nic = element.TEMPLATE.NIC;
+    var pci = element.TEMPLATE.PCI;
     var ips = [];
 
     var monitoring = element.MONITORING;
@@ -680,21 +696,35 @@ define(function(require) {
       })
     }
 
+    if (nic == undefined){
+      nic = [];
+    }
+
+    if (!$.isArray(nic)) {
+      nic = [nic];
+    }
+
+    if (pci != undefined) {
+      if (!$.isArray(pci)) {
+        pci = [pci];
+      }
+
+      $.each(pci, function(){
+        if (this["TYPE"] == "NIC"){
+          nic.push(this);
+        }
+      });
+    }
+
     if(ips.length==0)
     {
-      if (nic != undefined) {
-        if (!$.isArray(nic)) {
-          nic = [nic];
-        }
-
-        $.each(nic, function(index, value) {
-          $.each(NIC_IP_ATTRS, function(j, attr){
-            if (value[attr]) {
-              ips.push(value[attr]);
-            }
-          });
+      $.each(nic, function(index, value) {
+        $.each(NIC_IP_ATTRS, function(j, attr){
+          if (value[attr]) {
+            ips.push(value[attr]);
+          }
         });
-      }
+      });
     }
 
     if (ips.length > 0) {
