@@ -38,17 +38,14 @@ define(function(require) {
   };
 
   var _addMainTabs = function() {
+    _addActions();
+
     $.each(Config.enabledTabs, function(i, tabName){
       var name = './tabs/' + tabName;
       var tabObj = require(name);
       var _tabId = tabObj.tabId;
       SunstoneCfg["tabs"][_tabId] = tabObj;
 
-      var actions = tabObj.actions;
-      if (actions) {
-        _addActions(actions)
-      }
-
       var panels = tabObj.panels;
       if (panels) {
         _addPanels(_tabId, panels)
@@ -76,11 +73,18 @@ define(function(require) {
     });
   }
 
-  var _addActions = function(actions) {
-    $.each(actions, function(actionName, action) {
-      SunstoneCfg["actions"][actionName] = action;
-    })
-    return false;
+  var _addActions = function() {
+    $.each(Config.allTabs(), function(i, tabName){
+      var name = './tabs/' + tabName;
+      var tabObj = require(name);
+
+      var actions = tabObj.actions;
+      if (actions) {
+        $.each(actions, function(actionName, action) {
+          SunstoneCfg["actions"][actionName] = action;
+        });
+      }
+    });
   }
 
   var _addDialogs = function(dialogs) {
@@ -422,7 +426,7 @@ define(function(require) {
 
       if ($("#" + customId + "labels_buttons button", buttonsRow).length != 0) {
         $('#' + customId + 'labels_buttons').append(
-          '<div id="' + customId + 'LabelsDropdown" class="only-sunstone-info only-sunstone-list labels-dropdown dropdown-pane menu vertical" data-dropdown data-close-on-click="true"></div>').foundation();
+          '<div id="' + customId + 'LabelsDropdown" class="only-sunstone-info only-sunstone-list labels-dropdown dropdown-pane large menu vertical" data-dropdown data-close-on-click="true"></div>').foundation();
       }
 
       //actionBlock.foundationButtons();
@@ -610,6 +614,10 @@ define(function(require) {
     }
   }
 
+  var _getTab = function() {
+    return $(".tab:visible").attr("id");
+  }
+
   var _showElement = function(tabName, infoAction, elementId) {
     _showTab(tabName);
 
@@ -959,13 +967,11 @@ define(function(require) {
    *                        tab will be used
    */
   function _hideFormPanelLoading(tabId) {
-    var context;
-    if (tabId){
-      context = $("#" + tabId);
-    } else {
-      context = $(".tab:visible");  // current tab
-      tabId = context.attr("id");
+    if (tabId == undefined){
+      tabId = _getTab()
     }
+
+    var context = $("#" + tabId);
     //$(".sunstone-form", context).html(content);
 
     $(".loadingForm", context).hide();
@@ -984,11 +990,19 @@ define(function(require) {
   }
 
   function _hideFormPanel(tabId) {
+    if (tabId == undefined){
+      tabId = _getTab()
+    }
+
     var context = $("#" + tabId);
     $('[href="back"]', context).trigger("click");
   }
 
   function _popFormPanelLoading(tabId) {
+    if (tabId == undefined){
+      tabId = _getTab()
+    }
+
     var context = $("#" + tabId);
     $(".sunstone-list", context).hide();
     $(".sunstone-info", context).hide();
@@ -1018,6 +1032,10 @@ define(function(require) {
   }
 
   function _enableFormPanelSubmit(tabId) {
+    if (tabId == undefined){
+      tabId = _getTab()
+    }
+
     var context = $("#" + tabId);
     $(".submit_button", context).
         removeAttr("disabled").
@@ -1099,6 +1117,7 @@ define(function(require) {
 
     'showTab': _showTab,
     "showElement" : _showElement,
+    "getTab": _getTab,
 
     "showFormPanel": _showFormPanel,
     "resetFormPanel": _resetFormPanel,
