@@ -24,6 +24,7 @@ define(function(require) {
   var Locale = require('utils/locale');
   var OpenNebulaService = require('opennebula/service');
   var LabelsUtils = require('utils/labels/utils');
+  var SearchDropdown = require('hbs!./datatable/search');
 
   /*
     CONSTANTS
@@ -33,6 +34,7 @@ define(function(require) {
   var XML_ROOT = "DOCUMENT";
   var TAB_NAME = require('./tabId');
   var LABELS_COLUMN = 6;
+  var SEARCH_COLUMN = 7;
   var TEMPLATE_ATTR = 'TEMPLATE';
 
   /*
@@ -65,7 +67,8 @@ define(function(require) {
       Locale.tr("Group"),
       Locale.tr("Name"),
       Locale.tr("State"),
-      Locale.tr("Labels")
+      Locale.tr("Labels"),
+      "search_data"
     ];
 
     this.selectOptions = {
@@ -77,6 +80,9 @@ define(function(require) {
       "you_selected_multiple": Locale.tr("You selected the following Services:")
     };
 
+    this.conf.searchDropdownHTML = SearchDropdown({tableId: this.dataTableId});
+    this.searchColumn = SEARCH_COLUMN;
+
     TabDataTable.call(this);
   }
 
@@ -93,6 +99,15 @@ define(function(require) {
   function _elementArray(element_json) {
     var element = element_json[XML_ROOT];
 
+    var state = OpenNebulaService.stateStr(element.TEMPLATE.BODY.state);
+
+    var search = {
+      NAME:  element.NAME,
+      UNAME: element.UNAME,
+      GNAME: element.GNAME,
+      STATE: state
+    }
+
     return [
         '<input class="check_item" type="checkbox" id="' + RESOURCE.toLowerCase() + '_' +
                              element.ID + '" name="selected_items" value="' +
@@ -101,8 +116,9 @@ define(function(require) {
         element.UNAME,
         element.GNAME,
         element.NAME,
-        OpenNebulaService.stateStr(element.TEMPLATE.BODY.state),
-        (LabelsUtils.labelsStr(element[TEMPLATE_ATTR])||'')
+        state,
+        (LabelsUtils.labelsStr(element[TEMPLATE_ATTR])||''),
+        btoa(unescape(encodeURIComponent(JSON.stringify(search))))
     ];
   }
 });
