@@ -26,6 +26,7 @@ define(function(require) {
   var TemplateUtils = require('utils/template-utils');
   var Sunstone = require('sunstone');
   var Notifier = require('utils/notifier');
+  var Humanize = require('utils/humanize');
 
   /*
     TEMPLATES
@@ -91,6 +92,15 @@ define(function(require) {
 
     $('#provision_user_views_select option[value="' + config['user_config']["default_view"] + '"]', context).attr('selected', 'selected');
 
+    var login_token = this.element.LOGIN_TOKEN.TOKEN;
+    if (login_token && login_token.length) {
+      $(".provision_login_token_current", context).show();
+      $(".provision_login_token_valid", context).text(Humanize.prettyTime(this.element.LOGIN_TOKEN.EXPIRATION_TIME));
+      $(".provision_login_token_value", context).text(this.element.LOGIN_TOKEN.TOKEN);
+    } else {
+      $(".provision_login_token_current", context).hide();
+    }
+
     $("#provision_change_password_form").submit(function() {
       var pw = $('#provision_new_password', this).val();
       var confirm_password = $('#provision_new_confirm_password', this).val();
@@ -126,6 +136,37 @@ define(function(require) {
       return false;
     });
 
+    $("#provision_login_token_form", context).submit(function() {
+      $(".provision_login_token_button", context).html('<i class="fa fa-spinner fa-spin"/>')
+
+      OpenNebula.User.login({
+        data : {
+          id: "-1",
+          'username': that.element.NAME,
+          //token
+          //expire
+        },
+        success: function(req, response){
+          OpenNebula.User.show({
+            data : {
+              id: that.element.ID
+            },
+            success: function(request, user_json){
+              $(".provision_login_token_button", context).text(Locale.tr("Get a login token"));
+
+              $(".provision_login_token_current", context).show();
+              $(".provision_login_token_valid", context).text(Humanize.prettyTime(user_json.USER.LOGIN_TOKEN.EXPIRATION_TIME));
+              $(".provision_login_token_value", context).text(user_json.USER.LOGIN_TOKEN.TOKEN);
+            },
+            error: Notifier.onError
+          });
+        },
+        error: Notifier.onError
+      });
+
+      return false;
+    });
+
     $("#provision_change_view_form").submit(function() {
       var sunstone_setting = {DEFAULT_VIEW : $('#provision_user_views_select', this).val()};
       Sunstone.runAction("User.append_sunstone_setting_refresh", that.element.ID, sunstone_setting);
