@@ -28,10 +28,10 @@ define(function(require) {
     CONSTANTS
    */
 
-  var TAB_ID = require('../tabId');
-  var PANEL_ID = require('./info/panelId');
-  var RESOURCE = "Support";
-  var XML_ROOT = "REQUEST";
+  var TAB_ID      = require('../tabId');
+  var PANEL_ID    = require('./info/panelId');
+  var RESOURCE    = "Support";
+  var XML_ROOT    = "REQUEST";
 
   /*
     CONSTRUCTOR
@@ -67,7 +67,7 @@ define(function(require) {
     var comments = [];
     if (this.element["comments"]) {
       $.each(this.element["comments"], function(index, comment){
-        var author = (comment["author_id"] == 21231023 ? "OpenNebula Support Team" : 'Me');
+        var author = (comment["author_id"] == config["support"]["author_id"] ? config["support"]["author_name"] : 'Me');
 
         comments.push({
           title: '<span style="width: 100%;">'+author+' <span style="color: #999;"> - '+comment["created_at"]+'</span></span>',
