@@ -26,6 +26,7 @@ define(function(require) {
   var QuotaWidgets = require('utils/quotas/quota-widgets');
   var TemplateUtils = require('utils/template-utils');
   var LabelsUtils = require('utils/labels/utils');
+  var SearchDropdown = require('hbs!./datatable/search');
 
   /*
     CONSTANTS
@@ -34,7 +35,8 @@ define(function(require) {
   var RESOURCE = "User";
   var XML_ROOT = "USER";
   var TAB_NAME = require('./tabId');
-  var LABELS_COLUMN = 10;
+  var LABELS_COLUMN = 11;
+  var SEARCH_COLUMN = 12;
   var TEMPLATE_ATTR = 'TEMPLATE';
 
   /*
@@ -54,9 +56,9 @@ define(function(require) {
       "bSortClasses" : false,
       "bDeferRender": true,
       "aoColumnDefs": [
-          { "bSortable": false, "aTargets": ["check",5,6,7] },
+          { "bSortable": false, "aTargets": ["check",6,7,8] },
           {"sWidth": "35px", "aTargets": [0]},
-          { "sWidth": "150px", "aTargets": [5,6,7] },
+          { "sWidth": "150px", "aTargets": [6,7,8] },
           {"bVisible": true, "aTargets": SunstoneConfig.tabTableColumns(TAB_NAME)},
           {"bVisible": false, "aTargets": ['_all']}
       ]
@@ -67,12 +69,14 @@ define(function(require) {
       Locale.tr("Name"),
       Locale.tr("Group"),
       Locale.tr("Auth driver"),
+      Locale.tr("Password"),
       Locale.tr("VMs"),
       Locale.tr("Memory"),
       Locale.tr("CPU"),
       Locale.tr("Group ID"),
       Locale.tr("Hidden User Data"),
-      Locale.tr("Labels")
+      Locale.tr("Labels"),
+      "search_data"
     ];
 
     this.selectOptions = {
@@ -86,6 +90,9 @@ define(function(require) {
 
     this.totalUsers = 0;
 
+    this.conf.searchDropdownHTML = SearchDropdown({tableId: this.dataTableId});
+    this.searchColumn = SEARCH_COLUMN;
+
     TabDataTable.call(this);
   }
 
@@ -134,20 +141,29 @@ define(function(require) {
     // Build hidden user template
     var hidden_template = TemplateUtils.templateToString(element);
 
+    var search = {
+      NAME:  element.NAME,
+      GNAME: element.GNAME,
+      PASSWORD: element.PASSWORD,
+      AUTH_DRIVER: element.AUTH_DRIVER
+    }
+
     return [
       '<input class="check_item" type="checkbox" id="'+RESOURCE.toLowerCase()+'_' +
-                           element.ID + '" name="selected_items" value="' +
-                           element.ID + '"/>',
+                           element.ID + '" name="selected_items" ' +
+                           'value="' + element.ID + '"/>',
       element.ID,
       element.NAME,
       element.GNAME,
       element.AUTH_DRIVER,
+      element.PASSWORD,
       vms,
       memory,
       cpu,
       element.GID,
       hidden_template,
-      (LabelsUtils.labelsStr(element[TEMPLATE_ATTR])||'')
+      (LabelsUtils.labelsStr(element[TEMPLATE_ATTR])||''),
+      btoa(unescape(encodeURIComponent(JSON.stringify(search))))
     ];
   }
 
