@@ -42,6 +42,8 @@ define(function(require) {
   var RESOURCE = "User";
   var XML_ROOT = "USER";
   var PASSWORD_DIALOG_ID = require('tabs/users-tab/dialogs/password/dialogId');
+  var LOGIN_TOKEN_DIALOG_ID = require('tabs/users-tab/dialogs/login-token/dialogId');
+  var CONFIRM_DIALOG_ID = require('utils/dialogs/generic-confirm/dialogId');
 
   /*
     CONSTRUCTOR
@@ -125,15 +127,30 @@ define(function(require) {
       }
     });
 
-    // SSH input
+    // View password button
+    context.off("click", "#view_password");
+    context.on("click", "#view_password", function(){
+      Sunstone.getDialog(CONFIRM_DIALOG_ID).setParams({
+        header : Locale.tr("Password"),
+        headerTabId: TAB_ID,
+        body: '<label>' + Locale.tr("Current password") + '</label>' +
+              '<pre>'+that.element.PASSWORD+'</pre>',
+        question : '',
+        buttons : [
+          Locale.tr("Close"),
+        ],
+        submit : [
+          function(){
+            return false;
+          }
+        ]
+      });
 
-    context.off("click", ".user_ssh_public_key_edit");
-    context.on("click", ".user_ssh_public_key_edit", function() {
-      $("#user_ssh_public_key_text", context).hide();
-      $("#user_ssh_public_key_textarea", context).show().focus();
+      Sunstone.getDialog(CONFIRM_DIALOG_ID).reset();
+      Sunstone.getDialog(CONFIRM_DIALOG_ID).show();
     });
 
-    // Password button
+    // Edit password button
     context.off("click", "#update_password");
     context.on("click", "#update_password", function(){
       Sunstone.getDialog(PASSWORD_DIALOG_ID).setParams(
@@ -142,6 +159,22 @@ define(function(require) {
       Sunstone.getDialog(PASSWORD_DIALOG_ID).show();
     });
 
+    // Login token button
+    context.off("click", "#login_token");
+    context.on("click", "#login_token", function(){
+      Sunstone.getDialog(LOGIN_TOKEN_DIALOG_ID).setParams({element: that.element});
+      Sunstone.getDialog(LOGIN_TOKEN_DIALOG_ID).reset();
+      Sunstone.getDialog(LOGIN_TOKEN_DIALOG_ID).show();
+    });
+
+    // SSH input
+
+    context.off("click", ".user_ssh_public_key_edit");
+    context.on("click", ".user_ssh_public_key_edit", function() {
+      $("#user_ssh_public_key_text", context).hide();
+      $("#user_ssh_public_key_textarea", context).show().focus();
+    });
+
     context.off("change", "#user_ssh_public_key_textarea");
     context.on("change", "#user_ssh_public_key_textarea", function() {
       var template_str = 'SSH_PUBLIC_KEY = "'+TemplateUtils.escapeDoubleQuotes($(this).val())+'"';
