@@ -127,6 +127,7 @@ define(function(require) {
       type: "custom",
       call: function() {
        var dialog = Sunstone.getDialog(MIGRATE_DIALOG_ID);
+       dialog.reset();
        dialog.setLive(false);
        dialog.show();
      }
@@ -135,6 +136,7 @@ define(function(require) {
       type: "custom",
       call: function() {
        var dialog = Sunstone.getDialog(MIGRATE_DIALOG_ID);
+       dialog.reset();
        dialog.setLive(true);
        dialog.show();
      }
@@ -215,8 +217,8 @@ define(function(require) {
 
         Sunstone.runAction("VM.refresh");
       },
-      elements: function() {
-        return Sunstone.getDataTable(TAB_ID).elements();
+      elements: function(opts) {
+        return Sunstone.getDataTable(TAB_ID).elements(opts);
       },
       error: function(request, response) {
         Sunstone.hideFormPanelLoading(TAB_ID);
