@@ -1,5 +1,5 @@
 /* -------------------------------------------------------------------------- */
-/* Copyright 2002-2015, OpenNebula Project, OpenNebula Systems                */
+/* Copyright 2002-2016, OpenNebula Project, OpenNebula Systems                */
 /*                                                                            */
 /* Licensed under the Apache License, Version 2.0 (the "License"); you may    */
 /* not use this file except in compliance with the License. You may obtain    */
@@ -111,13 +111,20 @@ define(function(require) {
 
         case "acct_owner_group":
           $("#acct_owner_select", context).show();
-          ResourceSelect.insert("#acct_owner_select", context, "Group");
+          ResourceSelect.insert({
+              context: $('#acct_owner_select', context),
+              resourceName: 'Group'
+            });
           break;
 
         case "acct_owner_user":
           $("#acct_owner_select", context).show();
-          ResourceSelect.insert("#acct_owner_select", context, "User", -1, false,
-              '<option value="-1">'+Locale.tr("<< me >>")+'</option>');
+          ResourceSelect.insert({
+              context: $('#acct_owner_select', context),
+              resourceName: 'User',
+              initValue: -1,
+              extraOptions: '<option value="-1">' + Locale.tr("<< me >>") + '</option>'
+            });
           break;
         }
       });
@@ -287,7 +294,7 @@ define(function(require) {
           color: "#999",
           size: 10
         },
-        ticks: 4,
+        ticks: 3,
         minTickSize: [1, "day"]
       },
       yaxis : { min: 0,
