@@ -19,6 +19,7 @@ define(function(require) {
   var TemplateUtils = require('utils/template-utils');
   var VNetsTable = require('tabs/vnets-tab/datatable');
   var RangeSlider = require('utils/range-slider');
+  var UniqueId = require('utils/unique-id');
 
   var TemplateHTML = require('hbs!./user-inputs/table');
   var RowTemplateHTML = require('hbs!./user-inputs/row');
@@ -266,7 +267,7 @@ define(function(require) {
 
       var vnetsTable;
       $.each(network_attrs, function(index, vnet_attr) {
-        var unique_id = "user_input_" + (vnet_attr.name.replace(/ /g, "_"));
+        var unique_id = "vnet_user_input_" + UniqueId.id();
         vnetsTable = new VNetsTable(unique_id, {'select': true});
 
         $(".instantiate_user_inputs", div).append(
@@ -506,7 +507,7 @@ define(function(require) {
           _attributeInput(attr_gb) +
         '</div>' +
         '<div class="input-group-button">'+
-          '<select id="mb_input_unit" style="width: auto;">' +
+          '<select id="mb_input_unit">' +
             '<option value="MB">'+Locale.tr("MB")+'</option>' +
             '<option value="GB" selected>'+Locale.tr("GB")+'</option>' +
           '</select>' +
@@ -528,7 +529,7 @@ define(function(require) {
 
   function _setupAttributeInputMB(context) {
     // MB to GB
-    $("div.mb_input", context).on("input", "input, select", function(){
+    $("div.mb_input", context).on("change", "input, select", function(){
       var val = "";
 
       if (this.value && this.value >= 0) {
@@ -539,7 +540,7 @@ define(function(require) {
     });
 
     // GB to MB
-    $("div.gb_input", context).on("input", "input, select", function(){
+    $("div.gb_input", context).on("change", "input, select", function(){
       var val = "";
 
       if (this.value && this.value >= 0) {
@@ -559,7 +560,7 @@ define(function(require) {
         $("div.mb_input", context).hide();
         gb_inputs.appendTo($("div.gb_input", context));
 
-        $("div.mb_input input,select",context).trigger("input");
+        $("input, select", $("div.mb_input",context)).trigger("change");
       } else {
         $("div.mb_input", context).show();
         gb_inputs = $("div.gb_input", context).children().detach();
