@@ -77,8 +77,7 @@ ONED_CONF_OPTS = {
         'DS_MAD_CONF',
         'MARKET_MAD_CONF',
         'VM_MAD',
-        'IM_MAD',
-        'AUTH_MAD'
+        'IM_MAD'
     ]
 }
 
@@ -383,6 +382,7 @@ before do
 
                 session[:active_zone_endpoint] = z['TEMPLATE/ENDPOINT']
                 session[:zone_name] = env['HTTP_ZONE_NAME']
+                session[:zone_id]   = z.id
             end
          }
 
@@ -511,8 +511,8 @@ get '/version' do
         end
     end
 
-    if !version[:version] || version[:version].empty?
-        version[:version] = OpenNebula::VERSION
+    if !version["version"] || version["version"].empty?
+        version["version"] = OpenNebula::VERSION
     end
 
     [200, version.to_json]
