@@ -1,5 +1,5 @@
 /* -------------------------------------------------------------------------- */
-/* Copyright 2002-2015, OpenNebula Project, OpenNebula Systems                */
+/* Copyright 2002-2016, OpenNebula Project, OpenNebula Systems                */
 /*                                                                            */
 /* Licensed under the Apache License, Version 2.0 (the "License"); you may    */
 /* not use this file except in compliance with the License. You may obtain    */
@@ -23,13 +23,13 @@
 #include "Nebula.h"
 #include "AuthManager.h"
 #include "NebulaUtil.h"
+#include "Client.h"
 
 #include <fstream>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
 
-#include <pwd.h>
 #include <stdlib.h>
 #include <fnmatch.h>
 
@@ -53,7 +53,7 @@ string UserPool::oneadmin_name;
 
 UserPool::UserPool(SqlDB * db,
                    time_t  __session_expiration_time,
-                   vector<const Attribute *> hook_mads,
+                   vector<const VectorAttribute *> hook_mads,
                    const string&             remotes_location,
                    bool                      is_federation_slave):
                        PoolSQL(db, User::table, !is_federation_slave, true)
@@ -66,12 +66,8 @@ UserPool::UserPool(SqlDB * db,
     string        one_token;
     string        one_name;
     string        one_pass;
-    string        one_auth_file;
     string        random;
 
-    const char *  one_auth;
-    ifstream      file;
-
     string        filenames[5];
     string        error_str;
 
@@ -106,43 +102,11 @@ UserPool::UserPool(SqlDB * db,
     }
 
     // User oneadmin needs to be added in the bootstrap
-    one_auth = getenv("ONE_AUTH");
-
-    if (!one_auth)
+    if ( Client::read_oneauth(one_token, error_str) != 0 )
     {
-        struct passwd * pw_ent;
-
-        pw_ent = getpwuid(getuid());
-
-        if ((pw_ent != NULL) && (pw_ent->pw_dir != NULL))
-        {
-            one_auth_file = pw_ent->pw_dir;
-            one_auth_file += "/.one/one_auth";
-
-            one_auth = one_auth_file.c_str();
-        }
-        else
-        {
-            goto error_no_file;
-        }
+        goto error_readoneauth;
     }
 
-    file.open(one_auth);
-
-    if (!file.good())
-    {
-        goto error_file;
-    }
-
-    getline(file,one_token);
-
-    if (file.fail())
-    {
-        goto error_file_read;
-    }
-
-    file.close();
-
     if (User::split_secret(one_token,one_name,one_pass) != 0)
     {
         goto error_token;
@@ -221,16 +185,8 @@ UserPool::UserPool(SqlDB * db,
 
     return;
 
-error_no_file:
-    oss << "Could not get one_auth file location";
-    goto error_common;
-
-error_file:
-    oss << "Could not open file: " << one_auth;
-    goto error_common;
-
-error_file_read:
-    oss << "Error reading file: " << one_auth;
+error_readoneauth:
+    oss << "Error reading one_auth: " << error_str;
     goto error_common;
 
 error_token:
@@ -330,7 +286,7 @@ int UserPool::allocate (
     user = new User(-1, gid, uname, gname, upass, auth_driver, enabled);
 
     // Add the primary group to the collection
-    user->add_collection_id(gid);
+    user->groups.add(gid);
 
     // Set a password for the OneGate tokens
     user->add_template_attribute("TOKEN_PASSWORD", one_util::random_password());
@@ -399,7 +355,7 @@ int UserPool::drop(PoolObjectSQL * objsql, string& error_msg)
 /* -------------------------------------------------------------------------- */
 /* -------------------------------------------------------------------------- */
 
-int UserPool::update(User * user)
+int UserPool::update(PoolObjectSQL * objsql)
 {
     if (Nebula::instance().is_federation_slave())
     {
@@ -410,7 +366,7 @@ int UserPool::update(User * user)
         return -1;
     }
 
-    return user->update(db);
+    return PoolSQL::update(objsql);
 }
 
 /* -------------------------------------------------------------------------- */
