@@ -1,5 +1,5 @@
 /* ------------------------------------------------------------------------ */
-/* Copyright 2002-2015, OpenNebula Project, OpenNebula Systems              */
+/* Copyright 2002-2016, OpenNebula Project, OpenNebula Systems              */
 /*                                                                          */
 /* Licensed under the Apache License, Version 2.0 (the "License"); you may  */
 /* not use this file except in compliance with the License. You may obtain  */
@@ -220,7 +220,7 @@ int VMTemplate::from_xml(const string& xml)
     rc += xpath(uname,      "/VMTEMPLATE/UNAME",   "not_found");
     rc += xpath(gname,      "/VMTEMPLATE/GNAME",   "not_found");
     rc += xpath(name,       "/VMTEMPLATE/NAME",    "not_found");
-    rc += xpath(regtime,    "/VMTEMPLATE/REGTIME", 0);
+    rc += xpath<time_t>(regtime, "/VMTEMPLATE/REGTIME", 0);
 
     // Permissions
     rc += perms_from_xml();
@@ -248,3 +248,15 @@ int VMTemplate::from_xml(const string& xml)
 
 /* ------------------------------------------------------------------------ */
 /* ------------------------------------------------------------------------ */
+
+bool VMTemplate::is_vrouter()
+{
+    bool vr;
+
+    get_template_attribute("VROUTER", vr);
+
+    return vr;
+}
+
+/* ------------------------------------------------------------------------ */
+/* ------------------------------------------------------------------------ */
